use super::Isotope;
use crate::Percent;

#[cfg(feature = "ranges")]
/// Range from the minimum to the maximum natural abundance across all isotopes
///
/// Only counts the isotopes that occur naturally in some amount, so the minimum is not 0.
///
/// Convenience constant to avoid writing the code below when this range is needed:
///
/// ```
/// use mendeleev::{Isotope, ISOTOPE_NATURAL_ABUNDANCE_RANGE};
/// let all_values = Isotope::iter().flat_map(|e| e.natural_abundance());
/// let min = all_values.clone().min_by(|a, b| a.total_cmp(&b)).unwrap();
/// let max = all_values.max_by(|a, b| a.total_cmp(&b)).unwrap();
/// assert_eq!(min..=max, ISOTOPE_NATURAL_ABUNDANCE_RANGE);
/// ```
pub const ISOTOPE_NATURAL_ABUNDANCE_RANGE: core::ops::RangeInclusive<Percent> =
    Percent(0.0002)..=Percent(100.0);

macro_rules! pct {
    ($value:literal) => {
        Some(Percent($value))
    };
}

impl Isotope {
    /// The isotopes relative natural abundance on Earth, as a percentage,
    /// or None if the isotope does not occur naturally or only in trace amounts
    ///
    /// ```
    /// use mendeleev::{Isotope, Percent};
    /// assert_eq!(Isotope::H1.natural_abundance(), Some(Percent(99.9855)));
    /// assert_eq!(Isotope::H3.natural_abundance(), None);
    /// assert_eq!(Isotope::Og295.natural_abundance(), None);
    /// ```
    pub const fn natural_abundance(&self) -> Option<Percent> {
        use Isotope::*;
        match self {
            H1 => pct!(99.9855),
            H2 => pct!(0.0145),
            H3 => None,
            H4 => None,
            H5 => None,
            H6 => None,
            H7 => None,
            He3 => pct!(0.0002),
            He4 => pct!(99.9998),
            He5 => None,
            He6 => None,
            He7 => None,
            He8 => None,
            He9 => None,
            He10 => None,
            Li3 => None,
            Li4 => None,
            Li5 => None,
            Li6 => pct!(4.85),
            Li7 => pct!(95.15),
            Li8 => None,
            Li9 => None,
            Li10 => None,
            Li11 => None,
            Li12 => None,
            Li13 => None,
            Be5 => None,
            Be6 => None,
            Be7 => None,
            Be8 => None,
            Be9 => pct!(100.0),
            Be10 => None,
            Be11 => None,
            Be12 => None,
            Be13 => None,
            Be14 => None,
            Be15 => None,
            Be16 => None,
            B6 => None,
            B7 => None,
            B8 => None,
            B9 => None,
            B10 => pct!(19.65),
            B11 => pct!(80.35),
            B12 => None,
            B13 => None,
            B14 => None,
            B15 => None,
            B16 => None,
            B17 => None,
            B18 => None,
            B19 => None,
            B20 => None,
            B21 => None,
            C8 => None,
            C9 => None,
            C10 => None,
            C11 => None,
            C12 => pct!(98.94),
            C13 => pct!(1.06),
            C14 => None,
            C15 => None,
            C16 => None,
            C17 => None,
            C18 => None,
            C19 => None,
            C20 => None,
            C21 => None,
            C22 => None,
            C23 => None,
            N10 => None,
            N11 => None,
            N12 => None,
            N13 => None,
            N14 => pct!(99.6205),
            N15 => pct!(0.3795),
            N16 => None,
            N17 => None,
            N18 => None,
            N19 => None,
            N20 => None,
            N21 => None,
            N22 => None,
            N23 => None,
            N24 => None,
            N25 => None,
            O11 => None,
            O12 => None,
            O13 => None,
            O14 => None,
            O15 => None,
            O16 => pct!(99.757),
            O17 => pct!(0.03835),
            O18 => pct!(0.2045),
            O19 => None,
            O20 => None,
            O21 => None,
            O22 => None,
            O23 => None,
            O24 => None,
            O25 => None,
            O26 => None,
            O27 => None,
            O28 => None,
            F13 => None,
            F14 => None,
            F15 => None,
            F16 => None,
            F17 => None,
            F18 => None,
            F19 => pct!(100.0),
            F20 => None,
            F21 => None,
            F22 => None,
            F23 => None,
            F24 => None,
            F25 => None,
            F26 => None,
            F27 => None,
            F28 => None,
            F29 => None,
            F30 => None,
            F31 => None,
            Ne15 => None,
            Ne16 => None,
            Ne17 => None,
            Ne18 => None,
            Ne19 => None,
            Ne20 => pct!(90.48),
            Ne21 => pct!(0.27),
            Ne22 => pct!(9.25),
            Ne23 => None,
            Ne24 => None,
            Ne25 => None,
            Ne26 => None,
            Ne27 => None,
            Ne28 => None,
            Ne29 => None,
            Ne30 => None,
            Ne31 => None,
            Ne32 => None,
            Ne33 => None,
            Ne34 => None,
            Na17 => None,
            Na18 => None,
            Na19 => None,
            Na20 => None,
            Na21 => None,
            Na22 => None,
            Na23 => pct!(100.0),
            Na24 => None,
            Na25 => None,
            Na26 => None,
            Na27 => None,
            Na28 => None,
            Na29 => None,
            Na30 => None,
            Na31 => None,
            Na32 => None,
            Na33 => None,
            Na34 => None,
            Na35 => None,
            Na36 => None,
            Na37 => None,
            Na38 => None,
            Na39 => None,
            Mg19 => None,
            Mg20 => None,
            Mg21 => None,
            Mg22 => None,
            Mg23 => None,
            Mg24 => pct!(78.965),
            Mg25 => pct!(10.011),
            Mg26 => pct!(11.025),
            Mg27 => None,
            Mg28 => None,
            Mg29 => None,
            Mg30 => None,
            Mg31 => None,
            Mg32 => None,
            Mg33 => None,
            Mg34 => None,
            Mg35 => None,
            Mg36 => None,
            Mg37 => None,
            Mg38 => None,
            Mg39 => None,
            Mg40 => None,
            Mg41 => None,
            Al21 => None,
            Al22 => None,
            Al23 => None,
            Al24 => None,
            Al25 => None,
            Al26 => None,
            Al27 => pct!(100.0),
            Al28 => None,
            Al29 => None,
            Al30 => None,
            Al31 => None,
            Al32 => None,
            Al33 => None,
            Al34 => None,
            Al35 => None,
            Al36 => None,
            Al37 => None,
            Al38 => None,
            Al39 => None,
            Al40 => None,
            Al41 => None,
            Al42 => None,
            Al43 => None,
            Si22 => None,
            Si23 => None,
            Si24 => None,
            Si25 => None,
            Si26 => None,
            Si27 => None,
            Si28 => pct!(92.2545),
            Si29 => pct!(4.672),
            Si30 => pct!(3.0735),
            Si31 => None,
            Si32 => None,
            Si33 => None,
            Si34 => None,
            Si35 => None,
            Si36 => None,
            Si37 => None,
            Si38 => None,
            Si39 => None,
            Si40 => None,
            Si41 => None,
            Si42 => None,
            Si43 => None,
            Si44 => None,
            Si45 => None,
            P24 => None,
            P25 => None,
            P26 => None,
            P27 => None,
            P28 => None,
            P29 => None,
            P30 => None,
            P31 => pct!(100.0),
            P32 => None,
            P33 => None,
            P34 => None,
            P35 => None,
            P36 => None,
            P37 => None,
            P38 => None,
            P39 => None,
            P40 => None,
            P41 => None,
            P42 => None,
            P43 => None,
            P44 => None,
            P45 => None,
            P46 => None,
            P47 => None,
            S26 => None,
            S27 => None,
            S28 => None,
            S29 => None,
            S30 => None,
            S31 => None,
            S32 => pct!(94.85),
            S33 => pct!(0.763),
            S34 => pct!(4.365),
            S35 => None,
            S36 => pct!(0.0158),
            S37 => None,
            S38 => None,
            S39 => None,
            S40 => None,
            S41 => None,
            S42 => None,
            S43 => None,
            S44 => None,
            S45 => None,
            S46 => None,
            S47 => None,
            S48 => None,
            S49 => None,
            Cl28 => None,
            Cl29 => None,
            Cl30 => None,
            Cl31 => None,
            Cl32 => None,
            Cl33 => None,
            Cl34 => None,
            Cl35 => pct!(75.8),
            Cl36 => None,
            Cl37 => pct!(24.2),
            Cl38 => None,
            Cl39 => None,
            Cl40 => None,
            Cl41 => None,
            Cl42 => None,
            Cl43 => None,
            Cl44 => None,
            Cl45 => None,
            Cl46 => None,
            Cl47 => None,
            Cl48 => None,
            Cl49 => None,
            Cl50 => None,
            Cl51 => None,
            Cl52 => None,
            Ar29 => None,
            Ar30 => None,
            Ar31 => None,
            Ar32 => None,
            Ar33 => None,
            Ar34 => None,
            Ar35 => None,
            Ar36 => pct!(0.3336),
            Ar37 => None,
            Ar38 => pct!(0.0629),
            Ar39 => None,
            Ar40 => pct!(99.6035),
            Ar41 => None,
            Ar42 => None,
            Ar43 => None,
            Ar44 => None,
            Ar45 => None,
            Ar46 => None,
            Ar47 => None,
            Ar48 => None,
            Ar49 => None,
            Ar50 => None,
            Ar51 => None,
            Ar52 => None,
            Ar53 => None,
            Ar54 => None,
            K31 => None,
            K32 => None,
            K33 => None,
            K34 => None,
            K35 => None,
            K36 => None,
            K37 => None,
            K38 => None,
            K39 => pct!(93.2581),
            K40 => pct!(0.0117),
            K41 => pct!(6.7302),
            K42 => None,
            K43 => None,
            K44 => None,
            K45 => None,
            K46 => None,
            K47 => None,
            K48 => None,
            K49 => None,
            K50 => None,
            K51 => None,
            K52 => None,
            K53 => None,
            K54 => None,
            K55 => None,
            K56 => None,
            K57 => None,
            K58 => None,
            K59 => None,
            Ca33 => None,
            Ca34 => None,
            Ca35 => None,
            Ca36 => None,
            Ca37 => None,
            Ca38 => None,
            Ca39 => None,
            Ca40 => pct!(96.941),
            Ca41 => None,
            Ca42 => pct!(0.647),
            Ca43 => pct!(0.135),
            Ca44 => pct!(2.086),
            Ca45 => None,
            Ca46 => pct!(0.004),
            Ca47 => None,
            Ca48 => pct!(0.187),
            Ca49 => None,
            Ca50 => None,
            Ca51 => None,
            Ca52 => None,
            Ca53 => None,
            Ca54 => None,
            Ca55 => None,
            Ca56 => None,
            Ca57 => None,
            Ca58 => None,
            Ca59 => None,
            Ca60 => None,
            Ca61 => None,
            Sc35 => None,
            Sc36 => None,
            Sc37 => None,
            Sc38 => None,
            Sc39 => None,
            Sc40 => None,
            Sc41 => None,
            Sc42 => None,
            Sc43 => None,
            Sc44 => None,
            Sc45 => pct!(100.0),
            Sc46 => None,
            Sc47 => None,
            Sc48 => None,
            Sc49 => None,
            Sc50 => None,
            Sc51 => None,
            Sc52 => None,
            Sc53 => None,
            Sc54 => None,
            Sc55 => None,
            Sc56 => None,
            Sc57 => None,
            Sc58 => None,
            Sc59 => None,
            Sc60 => None,
            Sc61 => None,
            Sc62 => None,
            Sc63 => None,
            Ti37 => None,
            Ti38 => None,
            Ti39 => None,
            Ti40 => None,
            Ti41 => None,
            Ti42 => None,
            Ti43 => None,
            Ti44 => None,
            Ti45 => None,
            Ti46 => pct!(8.25),
            Ti47 => pct!(7.44),
            Ti48 => pct!(73.72),
            Ti49 => pct!(5.41),
            Ti50 => pct!(5.18),
            Ti51 => None,
            Ti52 => None,
            Ti53 => None,
            Ti54 => None,
            Ti55 => None,
            Ti56 => None,
            Ti57 => None,
            Ti58 => None,
            Ti59 => None,
            Ti60 => None,
            Ti61 => None,
            Ti62 => None,
            Ti63 => None,
            Ti64 => None,
            Ti65 => None,
            V39 => None,
            V40 => None,
            V41 => None,
            V42 => None,
            V43 => None,
            V44 => None,
            V45 => None,
            V46 => None,
            V47 => None,
            V48 => None,
            V49 => None,
            V50 => pct!(0.25),
            V51 => pct!(99.75),
            V52 => None,
            V53 => None,
            V54 => None,
            V55 => None,
            V56 => None,
            V57 => None,
            V58 => None,
            V59 => None,
            V60 => None,
            V61 => None,
            V62 => None,
            V63 => None,
            V64 => None,
            V65 => None,
            V66 => None,
            V67 => None,
            Cr41 => None,
            Cr42 => None,
            Cr43 => None,
            Cr44 => None,
            Cr45 => None,
            Cr46 => None,
            Cr47 => None,
            Cr48 => None,
            Cr49 => None,
            Cr50 => pct!(4.345),
            Cr51 => None,
            Cr52 => pct!(83.789),
            Cr53 => pct!(9.501),
            Cr54 => pct!(2.365),
            Cr55 => None,
            Cr56 => None,
            Cr57 => None,
            Cr58 => None,
            Cr59 => None,
            Cr60 => None,
            Cr61 => None,
            Cr62 => None,
            Cr63 => None,
            Cr64 => None,
            Cr65 => None,
            Cr66 => None,
            Cr67 => None,
            Cr68 => None,
            Cr69 => None,
            Cr70 => None,
            Mn43 => None,
            Mn44 => None,
            Mn45 => None,
            Mn46 => None,
            Mn47 => None,
            Mn48 => None,
            Mn49 => None,
            Mn50 => None,
            Mn51 => None,
            Mn52 => None,
            Mn53 => None,
            Mn54 => None,
            Mn55 => pct!(100.0),
            Mn56 => None,
            Mn57 => None,
            Mn58 => None,
            Mn59 => None,
            Mn60 => None,
            Mn61 => None,
            Mn62 => None,
            Mn63 => None,
            Mn64 => None,
            Mn65 => None,
            Mn66 => None,
            Mn67 => None,
            Mn68 => None,
            Mn69 => None,
            Mn70 => None,
            Mn71 => None,
            Mn72 => None,
            Mn73 => None,
            Fe45 => None,
            Fe46 => None,
            Fe47 => None,
            Fe48 => None,
            Fe49 => None,
            Fe50 => None,
            Fe51 => None,
            Fe52 => None,
            Fe53 => None,
            Fe54 => pct!(5.845),
            Fe55 => None,
            Fe56 => pct!(91.754),
            Fe57 => pct!(2.119),
            Fe58 => pct!(0.282),
            Fe59 => None,
            Fe60 => None,
            Fe61 => None,
            Fe62 => None,
            Fe63 => None,
            Fe64 => None,
            Fe65 => None,
            Fe66 => None,
            Fe67 => None,
            Fe68 => None,
            Fe69 => None,
            Fe70 => None,
            Fe71 => None,
            Fe72 => None,
            Fe73 => None,
            Fe74 => None,
            Fe75 => None,
            Fe76 => None,
            Co47 => None,
            Co48 => None,
            Co49 => None,
            Co50 => None,
            Co51 => None,
            Co52 => None,
            Co53 => None,
            Co54 => None,
            Co55 => None,
            Co56 => None,
            Co57 => None,
            Co58 => None,
            Co59 => pct!(100.0),
            Co60 => None,
            Co61 => None,
            Co62 => None,
            Co63 => None,
            Co64 => None,
            Co65 => None,
            Co66 => None,
            Co67 => None,
            Co68 => None,
            Co69 => None,
            Co70 => None,
            Co71 => None,
            Co72 => None,
            Co73 => None,
            Co74 => None,
            Co75 => None,
            Co76 => None,
            Co77 => None,
            Co78 => None,
            Ni48 => None,
            Ni49 => None,
            Ni50 => None,
            Ni51 => None,
            Ni52 => None,
            Ni53 => None,
            Ni54 => None,
            Ni55 => None,
            Ni56 => None,
            Ni57 => None,
            Ni58 => pct!(68.0769),
            Ni59 => None,
            Ni60 => pct!(26.2231),
            Ni61 => pct!(1.1399),
            Ni62 => pct!(3.6345),
            Ni63 => None,
            Ni64 => pct!(0.9256),
            Ni65 => None,
            Ni66 => None,
            Ni67 => None,
            Ni68 => None,
            Ni69 => None,
            Ni70 => None,
            Ni71 => None,
            Ni72 => None,
            Ni73 => None,
            Ni74 => None,
            Ni75 => None,
            Ni76 => None,
            Ni77 => None,
            Ni78 => None,
            Ni79 => None,
            Ni80 => None,
            Ni81 => None,
            Ni82 => None,
            Cu52 => None,
            Cu53 => None,
            Cu54 => None,
            Cu55 => None,
            Cu56 => None,
            Cu57 => None,
            Cu58 => None,
            Cu59 => None,
            Cu60 => None,
            Cu61 => None,
            Cu62 => None,
            Cu63 => pct!(69.15),
            Cu64 => None,
            Cu65 => pct!(30.85),
            Cu66 => None,
            Cu67 => None,
            Cu68 => None,
            Cu69 => None,
            Cu70 => None,
            Cu71 => None,
            Cu72 => None,
            Cu73 => None,
            Cu74 => None,
            Cu75 => None,
            Cu76 => None,
            Cu77 => None,
            Cu78 => None,
            Cu79 => None,
            Cu80 => None,
            Cu81 => None,
            Cu82 => None,
            Cu83 => None,
            Cu84 => None,
            Zn54 => None,
            Zn55 => None,
            Zn56 => None,
            Zn57 => None,
            Zn58 => None,
            Zn59 => None,
            Zn60 => None,
            Zn61 => None,
            Zn62 => None,
            Zn63 => None,
            Zn64 => pct!(49.17),
            Zn65 => None,
            Zn66 => pct!(27.73),
            Zn67 => pct!(4.04),
            Zn68 => pct!(18.45),
            Zn69 => None,
            Zn70 => pct!(0.61),
            Zn71 => None,
            Zn72 => None,
            Zn73 => None,
            Zn74 => None,
            Zn75 => None,
            Zn76 => None,
            Zn77 => None,
            Zn78 => None,
            Zn79 => None,
            Zn80 => None,
            Zn81 => None,
            Zn82 => None,
            Zn83 => None,
            Zn84 => None,
            Zn85 => None,
            Zn86 => None,
            Ga56 => None,
            Ga57 => None,
            Ga58 => None,
            Ga59 => None,
            Ga60 => None,
            Ga61 => None,
            Ga62 => None,
            Ga63 => None,
            Ga64 => None,
            Ga65 => None,
            Ga66 => None,
            Ga67 => None,
            Ga68 => None,
            Ga69 => pct!(60.108),
            Ga70 => None,
            Ga71 => pct!(39.892),
            Ga72 => None,
            Ga73 => None,
            Ga74 => None,
            Ga75 => None,
            Ga76 => None,
            Ga77 => None,
            Ga78 => None,
            Ga79 => None,
            Ga80 => None,
            Ga81 => None,
            Ga82 => None,
            Ga83 => None,
            Ga84 => None,
            Ga85 => None,
            Ga86 => None,
            Ga87 => None,
            Ga88 => None,
            Ge58 => None,
            Ge59 => None,
            Ge60 => None,
            Ge61 => None,
            Ge62 => None,
            Ge63 => None,
            Ge64 => None,
            Ge65 => None,
            Ge66 => None,
            Ge67 => None,
            Ge68 => None,
            Ge69 => None,
            Ge70 => pct!(20.52),
            Ge71 => None,
            Ge72 => pct!(27.45),
            Ge73 => pct!(7.76),
            Ge74 => pct!(36.52),
            Ge75 => None,
            Ge76 => pct!(7.75),
            Ge77 => None,
            Ge78 => None,
            Ge79 => None,
            Ge80 => None,
            Ge81 => None,
            Ge82 => None,
            Ge83 => None,
            Ge84 => None,
            Ge85 => None,
            Ge86 => None,
            Ge87 => None,
            Ge88 => None,
            Ge89 => None,
            Ge90 => None,
            As60 => None,
            As61 => None,
            As62 => None,
            As63 => None,
            As64 => None,
            As65 => None,
            As66 => None,
            As67 => None,
            As68 => None,
            As69 => None,
            As70 => None,
            As71 => None,
            As72 => None,
            As73 => None,
            As74 => None,
            As75 => pct!(100.0),
            As76 => None,
            As77 => None,
            As78 => None,
            As79 => None,
            As80 => None,
            As81 => None,
            As82 => None,
            As83 => None,
            As84 => None,
            As85 => None,
            As86 => None,
            As87 => None,
            As88 => None,
            As89 => None,
            As90 => None,
            As91 => None,
            As92 => None,
            Se63 => None,
            Se64 => None,
            Se65 => None,
            Se66 => None,
            Se67 => None,
            Se68 => None,
            Se69 => None,
            Se70 => None,
            Se71 => None,
            Se72 => None,
            Se73 => None,
            Se74 => pct!(0.86),
            Se75 => None,
            Se76 => pct!(9.23),
            Se77 => pct!(7.6),
            Se78 => pct!(23.69),
            Se79 => None,
            Se80 => pct!(49.8),
            Se81 => None,
            Se82 => pct!(8.82),
            Se83 => None,
            Se84 => None,
            Se85 => None,
            Se86 => None,
            Se87 => None,
            Se88 => None,
            Se89 => None,
            Se90 => None,
            Se91 => None,
            Se92 => None,
            Se93 => None,
            Se94 => None,
            Se95 => None,
            Br65 => None,
            Br66 => None,
            Br67 => None,
            Br68 => None,
            Br69 => None,
            Br70 => None,
            Br71 => None,
            Br72 => None,
            Br73 => None,
            Br74 => None,
            Br75 => None,
            Br76 => None,
            Br77 => None,
            Br78 => None,
            Br79 => pct!(50.65),
            Br80 => None,
            Br81 => pct!(49.35),
            Br82 => None,
            Br83 => None,
            Br84 => None,
            Br85 => None,
            Br86 => None,
            Br87 => None,
            Br88 => None,
            Br89 => None,
            Br90 => None,
            Br91 => None,
            Br92 => None,
            Br93 => None,
            Br94 => None,
            Br95 => None,
            Br96 => None,
            Br97 => None,
            Br98 => None,
            Kr67 => None,
            Kr68 => None,
            Kr69 => None,
            Kr70 => None,
            Kr71 => None,
            Kr72 => None,
            Kr73 => None,
            Kr74 => None,
            Kr75 => None,
            Kr76 => None,
            Kr77 => None,
            Kr78 => pct!(0.355),
            Kr79 => None,
            Kr80 => pct!(2.286),
            Kr81 => None,
            Kr82 => pct!(11.593),
            Kr83 => pct!(11.5),
            Kr84 => pct!(56.987),
            Kr85 => None,
            Kr86 => pct!(17.279),
            Kr87 => None,
            Kr88 => None,
            Kr89 => None,
            Kr90 => None,
            Kr91 => None,
            Kr92 => None,
            Kr93 => None,
            Kr94 => None,
            Kr95 => None,
            Kr96 => None,
            Kr97 => None,
            Kr98 => None,
            Kr99 => None,
            Kr100 => None,
            Kr101 => None,
            Rb71 => None,
            Rb72 => None,
            Rb73 => None,
            Rb74 => None,
            Rb75 => None,
            Rb76 => None,
            Rb77 => None,
            Rb78 => None,
            Rb79 => None,
            Rb80 => None,
            Rb81 => None,
            Rb82 => None,
            Rb83 => None,
            Rb84 => None,
            Rb85 => pct!(72.17),
            Rb86 => None,
            Rb87 => pct!(27.83),
            Rb88 => None,
            Rb89 => None,
            Rb90 => None,
            Rb91 => None,
            Rb92 => None,
            Rb93 => None,
            Rb94 => None,
            Rb95 => None,
            Rb96 => None,
            Rb97 => None,
            Rb98 => None,
            Rb99 => None,
            Rb100 => None,
            Rb101 => None,
            Rb102 => None,
            Rb103 => None,
            Rb104 => None,
            Sr73 => None,
            Sr74 => None,
            Sr75 => None,
            Sr76 => None,
            Sr77 => None,
            Sr78 => None,
            Sr79 => None,
            Sr80 => None,
            Sr81 => None,
            Sr82 => None,
            Sr83 => None,
            Sr84 => pct!(0.56),
            Sr85 => None,
            Sr86 => pct!(9.86),
            Sr87 => pct!(7.0),
            Sr88 => pct!(82.58),
            Sr89 => None,
            Sr90 => None,
            Sr91 => None,
            Sr92 => None,
            Sr93 => None,
            Sr94 => None,
            Sr95 => None,
            Sr96 => None,
            Sr97 => None,
            Sr98 => None,
            Sr99 => None,
            Sr100 => None,
            Sr101 => None,
            Sr102 => None,
            Sr103 => None,
            Sr104 => None,
            Sr105 => None,
            Sr106 => None,
            Sr107 => None,
            Y75 => None,
            Y76 => None,
            Y77 => None,
            Y78 => None,
            Y79 => None,
            Y80 => None,
            Y81 => None,
            Y82 => None,
            Y83 => None,
            Y84 => None,
            Y85 => None,
            Y86 => None,
            Y87 => None,
            Y88 => None,
            Y89 => pct!(100.0),
            Y90 => None,
            Y91 => None,
            Y92 => None,
            Y93 => None,
            Y94 => None,
            Y95 => None,
            Y96 => None,
            Y97 => None,
            Y98 => None,
            Y99 => None,
            Y100 => None,
            Y101 => None,
            Y102 => None,
            Y103 => None,
            Y104 => None,
            Y105 => None,
            Y106 => None,
            Y107 => None,
            Y108 => None,
            Y109 => None,
            Zr77 => None,
            Zr78 => None,
            Zr79 => None,
            Zr80 => None,
            Zr81 => None,
            Zr82 => None,
            Zr83 => None,
            Zr84 => None,
            Zr85 => None,
            Zr86 => None,
            Zr87 => None,
            Zr88 => None,
            Zr89 => None,
            Zr90 => pct!(51.45),
            Zr91 => pct!(11.22),
            Zr92 => pct!(17.15),
            Zr93 => None,
            Zr94 => pct!(17.38),
            Zr95 => None,
            Zr96 => pct!(2.8),
            Zr97 => None,
            Zr98 => None,
            Zr99 => None,
            Zr100 => None,
            Zr101 => None,
            Zr102 => None,
            Zr103 => None,
            Zr104 => None,
            Zr105 => None,
            Zr106 => None,
            Zr107 => None,
            Zr108 => None,
            Zr109 => None,
            Zr110 => None,
            Zr111 => None,
            Zr112 => None,
            Zr113 => None,
            Nb79 => None,
            Nb80 => None,
            Nb81 => None,
            Nb82 => None,
            Nb83 => None,
            Nb84 => None,
            Nb85 => None,
            Nb86 => None,
            Nb87 => None,
            Nb88 => None,
            Nb89 => None,
            Nb90 => None,
            Nb91 => None,
            Nb92 => None,
            Nb93 => pct!(100.0),
            Nb94 => None,
            Nb95 => None,
            Nb96 => None,
            Nb97 => None,
            Nb98 => None,
            Nb99 => None,
            Nb100 => None,
            Nb101 => None,
            Nb102 => None,
            Nb103 => None,
            Nb104 => None,
            Nb105 => None,
            Nb106 => None,
            Nb107 => None,
            Nb108 => None,
            Nb109 => None,
            Nb110 => None,
            Nb111 => None,
            Nb112 => None,
            Nb113 => None,
            Nb114 => None,
            Nb115 => None,
            Nb116 => None,
            Mo81 => None,
            Mo82 => None,
            Mo83 => None,
            Mo84 => None,
            Mo85 => None,
            Mo86 => None,
            Mo87 => None,
            Mo88 => None,
            Mo89 => None,
            Mo90 => None,
            Mo91 => None,
            Mo92 => pct!(14.649),
            Mo93 => None,
            Mo94 => pct!(9.187),
            Mo95 => pct!(15.873),
            Mo96 => pct!(16.673),
            Mo97 => pct!(9.582),
            Mo98 => pct!(24.292),
            Mo99 => None,
            Mo100 => pct!(9.744),
            Mo101 => None,
            Mo102 => None,
            Mo103 => None,
            Mo104 => None,
            Mo105 => None,
            Mo106 => None,
            Mo107 => None,
            Mo108 => None,
            Mo109 => None,
            Mo110 => None,
            Mo111 => None,
            Mo112 => None,
            Mo113 => None,
            Mo114 => None,
            Mo115 => None,
            Mo116 => None,
            Mo117 => None,
            Mo118 => None,
            Mo119 => None,
            Tc83 => None,
            Tc84 => None,
            Tc85 => None,
            Tc86 => None,
            Tc87 => None,
            Tc88 => None,
            Tc89 => None,
            Tc90 => None,
            Tc91 => None,
            Tc92 => None,
            Tc93 => None,
            Tc94 => None,
            Tc95 => None,
            Tc96 => None,
            Tc97 => None,
            Tc98 => None,
            Tc99 => None,
            Tc100 => None,
            Tc101 => None,
            Tc102 => None,
            Tc103 => None,
            Tc104 => None,
            Tc105 => None,
            Tc106 => None,
            Tc107 => None,
            Tc108 => None,
            Tc109 => None,
            Tc110 => None,
            Tc111 => None,
            Tc112 => None,
            Tc113 => None,
            Tc114 => None,
            Tc115 => None,
            Tc116 => None,
            Tc117 => None,
            Tc118 => None,
            Tc119 => None,
            Tc120 => None,
            Tc121 => None,
            Tc122 => None,
            Ru85 => None,
            Ru86 => None,
            Ru87 => None,
            Ru88 => None,
            Ru89 => None,
            Ru90 => None,
            Ru91 => None,
            Ru92 => None,
            Ru93 => None,
            Ru94 => None,
            Ru95 => None,
            Ru96 => pct!(5.54),
            Ru97 => None,
            Ru98 => pct!(1.87),
            Ru99 => pct!(12.76),
            Ru100 => pct!(12.6),
            Ru101 => pct!(17.06),
            Ru102 => pct!(31.55),
            Ru103 => None,
            Ru104 => pct!(18.62),
            Ru105 => None,
            Ru106 => None,
            Ru107 => None,
            Ru108 => None,
            Ru109 => None,
            Ru110 => None,
            Ru111 => None,
            Ru112 => None,
            Ru113 => None,
            Ru114 => None,
            Ru115 => None,
            Ru116 => None,
            Ru117 => None,
            Ru118 => None,
            Ru119 => None,
            Ru120 => None,
            Ru121 => None,
            Ru122 => None,
            Ru123 => None,
            Ru124 => None,
            Ru125 => None,
            Rh88 => None,
            Rh89 => None,
            Rh90 => None,
            Rh91 => None,
            Rh92 => None,
            Rh93 => None,
            Rh94 => None,
            Rh95 => None,
            Rh96 => None,
            Rh97 => None,
            Rh98 => None,
            Rh99 => None,
            Rh100 => None,
            Rh101 => None,
            Rh102 => None,
            Rh103 => pct!(100.0),
            Rh104 => None,
            Rh105 => None,
            Rh106 => None,
            Rh107 => None,
            Rh108 => None,
            Rh109 => None,
            Rh110 => None,
            Rh111 => None,
            Rh112 => None,
            Rh113 => None,
            Rh114 => None,
            Rh115 => None,
            Rh116 => None,
            Rh117 => None,
            Rh118 => None,
            Rh119 => None,
            Rh120 => None,
            Rh121 => None,
            Rh122 => None,
            Rh123 => None,
            Rh124 => None,
            Rh125 => None,
            Rh126 => None,
            Rh127 => None,
            Rh128 => None,
            Pd90 => None,
            Pd91 => None,
            Pd92 => None,
            Pd93 => None,
            Pd94 => None,
            Pd95 => None,
            Pd96 => None,
            Pd97 => None,
            Pd98 => None,
            Pd99 => None,
            Pd100 => None,
            Pd101 => None,
            Pd102 => pct!(1.02),
            Pd103 => None,
            Pd104 => pct!(11.14),
            Pd105 => pct!(22.33),
            Pd106 => pct!(27.33),
            Pd107 => None,
            Pd108 => pct!(26.46),
            Pd109 => None,
            Pd110 => pct!(11.72),
            Pd111 => None,
            Pd112 => None,
            Pd113 => None,
            Pd114 => None,
            Pd115 => None,
            Pd116 => None,
            Pd117 => None,
            Pd118 => None,
            Pd119 => None,
            Pd120 => None,
            Pd121 => None,
            Pd122 => None,
            Pd123 => None,
            Pd124 => None,
            Pd125 => None,
            Pd126 => None,
            Pd127 => None,
            Pd128 => None,
            Pd129 => None,
            Pd130 => None,
            Pd131 => None,
            Ag92 => None,
            Ag93 => None,
            Ag94 => None,
            Ag95 => None,
            Ag96 => None,
            Ag97 => None,
            Ag98 => None,
            Ag99 => None,
            Ag100 => None,
            Ag101 => None,
            Ag102 => None,
            Ag103 => None,
            Ag104 => None,
            Ag105 => None,
            Ag106 => None,
            Ag107 => pct!(51.839),
            Ag108 => None,
            Ag109 => pct!(48.161),
            Ag110 => None,
            Ag111 => None,
            Ag112 => None,
            Ag113 => None,
            Ag114 => None,
            Ag115 => None,
            Ag116 => None,
            Ag117 => None,
            Ag118 => None,
            Ag119 => None,
            Ag120 => None,
            Ag121 => None,
            Ag122 => None,
            Ag123 => None,
            Ag124 => None,
            Ag125 => None,
            Ag126 => None,
            Ag127 => None,
            Ag128 => None,
            Ag129 => None,
            Ag130 => None,
            Ag131 => None,
            Ag132 => None,
            Ag133 => None,
            Cd94 => None,
            Cd95 => None,
            Cd96 => None,
            Cd97 => None,
            Cd98 => None,
            Cd99 => None,
            Cd100 => None,
            Cd101 => None,
            Cd102 => None,
            Cd103 => None,
            Cd104 => None,
            Cd105 => None,
            Cd106 => pct!(1.245),
            Cd107 => None,
            Cd108 => pct!(0.888),
            Cd109 => None,
            Cd110 => pct!(12.47),
            Cd111 => pct!(12.795),
            Cd112 => pct!(24.109),
            Cd113 => pct!(12.227),
            Cd114 => pct!(28.754),
            Cd115 => None,
            Cd116 => pct!(7.512),
            Cd117 => None,
            Cd118 => None,
            Cd119 => None,
            Cd120 => None,
            Cd121 => None,
            Cd122 => None,
            Cd123 => None,
            Cd124 => None,
            Cd125 => None,
            Cd126 => None,
            Cd127 => None,
            Cd128 => None,
            Cd129 => None,
            Cd130 => None,
            Cd131 => None,
            Cd132 => None,
            Cd133 => None,
            Cd134 => None,
            Cd135 => None,
            In96 => None,
            In97 => None,
            In98 => None,
            In99 => None,
            In100 => None,
            In101 => None,
            In102 => None,
            In103 => None,
            In104 => None,
            In105 => None,
            In106 => None,
            In107 => None,
            In108 => None,
            In109 => None,
            In110 => None,
            In111 => None,
            In112 => None,
            In113 => pct!(4.281),
            In114 => None,
            In115 => pct!(95.719),
            In116 => None,
            In117 => None,
            In118 => None,
            In119 => None,
            In120 => None,
            In121 => None,
            In122 => None,
            In123 => None,
            In124 => None,
            In125 => None,
            In126 => None,
            In127 => None,
            In128 => None,
            In129 => None,
            In130 => None,
            In131 => None,
            In132 => None,
            In133 => None,
            In134 => None,
            In135 => None,
            In136 => None,
            In137 => None,
            Sn99 => None,
            Sn100 => None,
            Sn101 => None,
            Sn102 => None,
            Sn103 => None,
            Sn104 => None,
            Sn105 => None,
            Sn106 => None,
            Sn107 => None,
            Sn108 => None,
            Sn109 => None,
            Sn110 => None,
            Sn111 => None,
            Sn112 => pct!(0.97),
            Sn113 => None,
            Sn114 => pct!(0.66),
            Sn115 => pct!(0.34),
            Sn116 => pct!(14.54),
            Sn117 => pct!(7.68),
            Sn118 => pct!(24.22),
            Sn119 => pct!(8.59),
            Sn120 => pct!(32.58),
            Sn121 => None,
            Sn122 => pct!(4.63),
            Sn123 => None,
            Sn124 => pct!(5.79),
            Sn125 => None,
            Sn126 => None,
            Sn127 => None,
            Sn128 => None,
            Sn129 => None,
            Sn130 => None,
            Sn131 => None,
            Sn132 => None,
            Sn133 => None,
            Sn134 => None,
            Sn135 => None,
            Sn136 => None,
            Sn137 => None,
            Sn138 => None,
            Sn139 => None,
            Sn140 => None,
            Sb102 => None,
            Sb103 => None,
            Sb104 => None,
            Sb105 => None,
            Sb106 => None,
            Sb107 => None,
            Sb108 => None,
            Sb109 => None,
            Sb110 => None,
            Sb111 => None,
            Sb112 => None,
            Sb113 => None,
            Sb114 => None,
            Sb115 => None,
            Sb116 => None,
            Sb117 => None,
            Sb118 => None,
            Sb119 => None,
            Sb120 => None,
            Sb121 => pct!(57.21),
            Sb122 => None,
            Sb123 => pct!(42.79),
            Sb124 => None,
            Sb125 => None,
            Sb126 => None,
            Sb127 => None,
            Sb128 => None,
            Sb129 => None,
            Sb130 => None,
            Sb131 => None,
            Sb132 => None,
            Sb133 => None,
            Sb134 => None,
            Sb135 => None,
            Sb136 => None,
            Sb137 => None,
            Sb138 => None,
            Sb139 => None,
            Sb140 => None,
            Sb141 => None,
            Sb142 => None,
            Te104 => None,
            Te105 => None,
            Te106 => None,
            Te107 => None,
            Te108 => None,
            Te109 => None,
            Te110 => None,
            Te111 => None,
            Te112 => None,
            Te113 => None,
            Te114 => None,
            Te115 => None,
            Te116 => None,
            Te117 => None,
            Te118 => None,
            Te119 => None,
            Te120 => pct!(0.09),
            Te121 => None,
            Te122 => pct!(2.55),
            Te123 => pct!(0.89),
            Te124 => pct!(4.74),
            Te125 => pct!(7.07),
            Te126 => pct!(8.84),
            Te127 => None,
            Te128 => pct!(31.74),
            Te129 => None,
            Te130 => pct!(34.08),
            Te131 => None,
            Te132 => None,
            Te133 => None,
            Te134 => None,
            Te135 => None,
            Te136 => None,
            Te137 => None,
            Te138 => None,
            Te139 => None,
            Te140 => None,
            Te141 => None,
            Te142 => None,
            Te143 => None,
            Te144 => None,
            Te145 => None,
            I106 => None,
            I107 => None,
            I108 => None,
            I109 => None,
            I110 => None,
            I111 => None,
            I112 => None,
            I113 => None,
            I114 => None,
            I115 => None,
            I116 => None,
            I117 => None,
            I118 => None,
            I119 => None,
            I120 => None,
            I121 => None,
            I122 => None,
            I123 => None,
            I124 => None,
            I125 => None,
            I126 => None,
            I127 => pct!(100.0),
            I128 => None,
            I129 => None,
            I130 => None,
            I131 => None,
            I132 => None,
            I133 => None,
            I134 => None,
            I135 => None,
            I136 => None,
            I137 => None,
            I138 => None,
            I139 => None,
            I140 => None,
            I141 => None,
            I142 => None,
            I143 => None,
            I144 => None,
            I145 => None,
            I146 => None,
            I147 => None,
            Xe108 => None,
            Xe109 => None,
            Xe110 => None,
            Xe111 => None,
            Xe112 => None,
            Xe113 => None,
            Xe114 => None,
            Xe115 => None,
            Xe116 => None,
            Xe117 => None,
            Xe118 => None,
            Xe119 => None,
            Xe120 => None,
            Xe121 => None,
            Xe122 => None,
            Xe123 => None,
            Xe124 => pct!(0.095),
            Xe125 => None,
            Xe126 => pct!(0.089),
            Xe127 => None,
            Xe128 => pct!(1.91),
            Xe129 => pct!(26.401),
            Xe130 => pct!(4.071),
            Xe131 => pct!(21.232),
            Xe132 => pct!(26.909),
            Xe133 => None,
            Xe134 => pct!(10.436),
            Xe135 => None,
            Xe136 => pct!(8.857),
            Xe137 => None,
            Xe138 => None,
            Xe139 => None,
            Xe140 => None,
            Xe141 => None,
            Xe142 => None,
            Xe143 => None,
            Xe144 => None,
            Xe145 => None,
            Xe146 => None,
            Xe147 => None,
            Xe148 => None,
            Xe149 => None,
            Xe150 => None,
            Cs111 => None,
            Cs112 => None,
            Cs113 => None,
            Cs114 => None,
            Cs115 => None,
            Cs116 => None,
            Cs117 => None,
            Cs118 => None,
            Cs119 => None,
            Cs120 => None,
            Cs121 => None,
            Cs122 => None,
            Cs123 => None,
            Cs124 => None,
            Cs125 => None,
            Cs126 => None,
            Cs127 => None,
            Cs128 => None,
            Cs129 => None,
            Cs130 => None,
            Cs131 => None,
            Cs132 => None,
            Cs133 => pct!(100.0),
            Cs134 => None,
            Cs135 => None,
            Cs136 => None,
            Cs137 => None,
            Cs138 => None,
            Cs139 => None,
            Cs140 => None,
            Cs141 => None,
            Cs142 => None,
            Cs143 => None,
            Cs144 => None,
            Cs145 => None,
            Cs146 => None,
            Cs147 => None,
            Cs148 => None,
            Cs149 => None,
            Cs150 => None,
            Cs151 => None,
            Cs152 => None,
            Ba113 => None,
            Ba114 => None,
            Ba115 => None,
            Ba116 => None,
            Ba117 => None,
            Ba118 => None,
            Ba119 => None,
            Ba120 => None,
            Ba121 => None,
            Ba122 => None,
            Ba123 => None,
            Ba124 => None,
            Ba125 => None,
            Ba126 => None,
            Ba127 => None,
            Ba128 => None,
            Ba129 => None,
            Ba130 => pct!(0.11),
            Ba131 => None,
            Ba132 => pct!(0.1),
            Ba133 => None,
            Ba134 => pct!(2.42),
            Ba135 => pct!(6.59),
            Ba136 => pct!(7.85),
            Ba137 => pct!(11.23),
            Ba138 => pct!(71.7),
            Ba139 => None,
            Ba140 => None,
            Ba141 => None,
            Ba142 => None,
            Ba143 => None,
            Ba144 => None,
            Ba145 => None,
            Ba146 => None,
            Ba147 => None,
            Ba148 => None,
            Ba149 => None,
            Ba150 => None,
            Ba151 => None,
            Ba152 => None,
            Ba153 => None,
            Ba154 => None,
            La116 => None,
            La117 => None,
            La118 => None,
            La119 => None,
            La120 => None,
            La121 => None,
            La122 => None,
            La123 => None,
            La124 => None,
            La125 => None,
            La126 => None,
            La127 => None,
            La128 => None,
            La129 => None,
            La130 => None,
            La131 => None,
            La132 => None,
            La133 => None,
            La134 => None,
            La135 => None,
            La136 => None,
            La137 => None,
            La138 => pct!(0.08881),
            La139 => pct!(99.91119),
            La140 => None,
            La141 => None,
            La142 => None,
            La143 => None,
            La144 => None,
            La145 => None,
            La146 => None,
            La147 => None,
            La148 => None,
            La149 => None,
            La150 => None,
            La151 => None,
            La152 => None,
            La153 => None,
            La154 => None,
            La155 => None,
            La156 => None,
            La157 => None,
            Ce119 => None,
            Ce120 => None,
            Ce121 => None,
            Ce122 => None,
            Ce123 => None,
            Ce124 => None,
            Ce125 => None,
            Ce126 => None,
            Ce127 => None,
            Ce128 => None,
            Ce129 => None,
            Ce130 => None,
            Ce131 => None,
            Ce132 => None,
            Ce133 => None,
            Ce134 => None,
            Ce135 => None,
            Ce136 => pct!(0.186),
            Ce137 => None,
            Ce138 => pct!(0.251),
            Ce139 => None,
            Ce140 => pct!(88.449),
            Ce141 => None,
            Ce142 => pct!(11.114),
            Ce143 => None,
            Ce144 => None,
            Ce145 => None,
            Ce146 => None,
            Ce147 => None,
            Ce148 => None,
            Ce149 => None,
            Ce150 => None,
            Ce151 => None,
            Ce152 => None,
            Ce153 => None,
            Ce154 => None,
            Ce155 => None,
            Ce156 => None,
            Ce157 => None,
            Ce158 => None,
            Ce159 => None,
            Pr121 => None,
            Pr122 => None,
            Pr123 => None,
            Pr124 => None,
            Pr125 => None,
            Pr126 => None,
            Pr127 => None,
            Pr128 => None,
            Pr129 => None,
            Pr130 => None,
            Pr131 => None,
            Pr132 => None,
            Pr133 => None,
            Pr134 => None,
            Pr135 => None,
            Pr136 => None,
            Pr137 => None,
            Pr138 => None,
            Pr139 => None,
            Pr140 => None,
            Pr141 => pct!(100.0),
            Pr142 => None,
            Pr143 => None,
            Pr144 => None,
            Pr145 => None,
            Pr146 => None,
            Pr147 => None,
            Pr148 => None,
            Pr149 => None,
            Pr150 => None,
            Pr151 => None,
            Pr152 => None,
            Pr153 => None,
            Pr154 => None,
            Pr155 => None,
            Pr156 => None,
            Pr157 => None,
            Pr158 => None,
            Pr159 => None,
            Pr160 => None,
            Pr161 => None,
            Nd124 => None,
            Nd125 => None,
            Nd126 => None,
            Nd127 => None,
            Nd128 => None,
            Nd129 => None,
            Nd130 => None,
            Nd131 => None,
            Nd132 => None,
            Nd133 => None,
            Nd134 => None,
            Nd135 => None,
            Nd136 => None,
            Nd137 => None,
            Nd138 => None,
            Nd139 => None,
            Nd140 => None,
            Nd141 => None,
            Nd142 => pct!(27.153),
            Nd143 => pct!(12.173),
            Nd144 => pct!(23.798),
            Nd145 => pct!(8.293),
            Nd146 => pct!(17.189),
            Nd147 => None,
            Nd148 => pct!(5.756),
            Nd149 => None,
            Nd150 => pct!(5.638),
            Nd151 => None,
            Nd152 => None,
            Nd153 => None,
            Nd154 => None,
            Nd155 => None,
            Nd156 => None,
            Nd157 => None,
            Nd158 => None,
            Nd159 => None,
            Nd160 => None,
            Nd161 => None,
            Nd162 => None,
            Nd163 => None,
            Pm126 => None,
            Pm127 => None,
            Pm128 => None,
            Pm129 => None,
            Pm130 => None,
            Pm131 => None,
            Pm132 => None,
            Pm133 => None,
            Pm134 => None,
            Pm135 => None,
            Pm136 => None,
            Pm137 => None,
            Pm138 => None,
            Pm139 => None,
            Pm140 => None,
            Pm141 => None,
            Pm142 => None,
            Pm143 => None,
            Pm144 => None,
            Pm145 => None,
            Pm146 => None,
            Pm147 => None,
            Pm148 => None,
            Pm149 => None,
            Pm150 => None,
            Pm151 => None,
            Pm152 => None,
            Pm153 => None,
            Pm154 => None,
            Pm155 => None,
            Pm156 => None,
            Pm157 => None,
            Pm158 => None,
            Pm159 => None,
            Pm160 => None,
            Pm161 => None,
            Pm162 => None,
            Pm163 => None,
            Pm164 => None,
            Pm165 => None,
            Sm128 => None,
            Sm129 => None,
            Sm130 => None,
            Sm131 => None,
            Sm132 => None,
            Sm133 => None,
            Sm134 => None,
            Sm135 => None,
            Sm136 => None,
            Sm137 => None,
            Sm138 => None,
            Sm139 => None,
            Sm140 => None,
            Sm141 => None,
            Sm142 => None,
            Sm143 => None,
            Sm144 => pct!(3.08),
            Sm145 => None,
            Sm146 => None,
            Sm147 => pct!(15.0),
            Sm148 => pct!(11.25),
            Sm149 => pct!(13.82),
            Sm150 => pct!(7.37),
            Sm151 => None,
            Sm152 => pct!(26.74),
            Sm153 => None,
            Sm154 => pct!(22.74),
            Sm155 => None,
            Sm156 => None,
            Sm157 => None,
            Sm158 => None,
            Sm159 => None,
            Sm160 => None,
            Sm161 => None,
            Sm162 => None,
            Sm163 => None,
            Sm164 => None,
            Sm165 => None,
            Sm166 => None,
            Sm167 => None,
            Sm168 => None,
            Eu130 => None,
            Eu131 => None,
            Eu132 => None,
            Eu133 => None,
            Eu134 => None,
            Eu135 => None,
            Eu136 => None,
            Eu137 => None,
            Eu138 => None,
            Eu139 => None,
            Eu140 => None,
            Eu141 => None,
            Eu142 => None,
            Eu143 => None,
            Eu144 => None,
            Eu145 => None,
            Eu146 => None,
            Eu147 => None,
            Eu148 => None,
            Eu149 => None,
            Eu150 => None,
            Eu151 => pct!(47.81),
            Eu152 => None,
            Eu153 => pct!(52.19),
            Eu154 => None,
            Eu155 => None,
            Eu156 => None,
            Eu157 => None,
            Eu158 => None,
            Eu159 => None,
            Eu160 => None,
            Eu161 => None,
            Eu162 => None,
            Eu163 => None,
            Eu164 => None,
            Eu165 => None,
            Eu166 => None,
            Eu167 => None,
            Eu168 => None,
            Eu169 => None,
            Eu170 => None,
            Gd133 => None,
            Gd134 => None,
            Gd135 => None,
            Gd136 => None,
            Gd137 => None,
            Gd138 => None,
            Gd139 => None,
            Gd140 => None,
            Gd141 => None,
            Gd142 => None,
            Gd143 => None,
            Gd144 => None,
            Gd145 => None,
            Gd146 => None,
            Gd147 => None,
            Gd148 => None,
            Gd149 => None,
            Gd150 => None,
            Gd151 => None,
            Gd152 => pct!(0.2),
            Gd153 => None,
            Gd154 => pct!(2.18),
            Gd155 => pct!(14.8),
            Gd156 => pct!(20.47),
            Gd157 => pct!(15.65),
            Gd158 => pct!(24.84),
            Gd159 => None,
            Gd160 => pct!(21.86),
            Gd161 => None,
            Gd162 => None,
            Gd163 => None,
            Gd164 => None,
            Gd165 => None,
            Gd166 => None,
            Gd167 => None,
            Gd168 => None,
            Gd169 => None,
            Gd170 => None,
            Gd171 => None,
            Gd172 => None,
            Tb135 => None,
            Tb136 => None,
            Tb137 => None,
            Tb138 => None,
            Tb139 => None,
            Tb140 => None,
            Tb141 => None,
            Tb142 => None,
            Tb143 => None,
            Tb144 => None,
            Tb145 => None,
            Tb146 => None,
            Tb147 => None,
            Tb148 => None,
            Tb149 => None,
            Tb150 => None,
            Tb151 => None,
            Tb152 => None,
            Tb153 => None,
            Tb154 => None,
            Tb155 => None,
            Tb156 => None,
            Tb157 => None,
            Tb158 => None,
            Tb159 => pct!(100.0),
            Tb160 => None,
            Tb161 => None,
            Tb162 => None,
            Tb163 => None,
            Tb164 => None,
            Tb165 => None,
            Tb166 => None,
            Tb167 => None,
            Tb168 => None,
            Tb169 => None,
            Tb170 => None,
            Tb171 => None,
            Tb172 => None,
            Tb173 => None,
            Tb174 => None,
            Dy138 => None,
            Dy139 => None,
            Dy140 => None,
            Dy141 => None,
            Dy142 => None,
            Dy143 => None,
            Dy144 => None,
            Dy145 => None,
            Dy146 => None,
            Dy147 => None,
            Dy148 => None,
            Dy149 => None,
            Dy150 => None,
            Dy151 => None,
            Dy152 => None,
            Dy153 => None,
            Dy154 => None,
            Dy155 => None,
            Dy156 => pct!(0.056),
            Dy157 => None,
            Dy158 => pct!(0.095),
            Dy159 => None,
            Dy160 => pct!(2.329),
            Dy161 => pct!(18.889),
            Dy162 => pct!(25.475),
            Dy163 => pct!(24.896),
            Dy164 => pct!(28.26),
            Dy165 => None,
            Dy166 => None,
            Dy167 => None,
            Dy168 => None,
            Dy169 => None,
            Dy170 => None,
            Dy171 => None,
            Dy172 => None,
            Dy173 => None,
            Dy174 => None,
            Dy175 => None,
            Dy176 => None,
            Ho140 => None,
            Ho141 => None,
            Ho142 => None,
            Ho143 => None,
            Ho144 => None,
            Ho145 => None,
            Ho146 => None,
            Ho147 => None,
            Ho148 => None,
            Ho149 => None,
            Ho150 => None,
            Ho151 => None,
            Ho152 => None,
            Ho153 => None,
            Ho154 => None,
            Ho155 => None,
            Ho156 => None,
            Ho157 => None,
            Ho158 => None,
            Ho159 => None,
            Ho160 => None,
            Ho161 => None,
            Ho162 => None,
            Ho163 => None,
            Ho164 => None,
            Ho165 => pct!(100.0),
            Ho166 => None,
            Ho167 => None,
            Ho168 => None,
            Ho169 => None,
            Ho170 => None,
            Ho171 => None,
            Ho172 => None,
            Ho173 => None,
            Ho174 => None,
            Ho175 => None,
            Ho176 => None,
            Ho177 => None,
            Ho178 => None,
            Er142 => None,
            Er143 => None,
            Er144 => None,
            Er145 => None,
            Er146 => None,
            Er147 => None,
            Er148 => None,
            Er149 => None,
            Er150 => None,
            Er151 => None,
            Er152 => None,
            Er153 => None,
            Er154 => None,
            Er155 => None,
            Er156 => None,
            Er157 => None,
            Er158 => None,
            Er159 => None,
            Er160 => None,
            Er161 => None,
            Er162 => pct!(0.139),
            Er163 => None,
            Er164 => pct!(1.601),
            Er165 => None,
            Er166 => pct!(33.503),
            Er167 => pct!(22.869),
            Er168 => pct!(26.978),
            Er169 => None,
            Er170 => pct!(14.91),
            Er171 => None,
            Er172 => None,
            Er173 => None,
            Er174 => None,
            Er175 => None,
            Er176 => None,
            Er177 => None,
            Er178 => None,
            Er179 => None,
            Er180 => None,
            Tm144 => None,
            Tm145 => None,
            Tm146 => None,
            Tm147 => None,
            Tm148 => None,
            Tm149 => None,
            Tm150 => None,
            Tm151 => None,
            Tm152 => None,
            Tm153 => None,
            Tm154 => None,
            Tm155 => None,
            Tm156 => None,
            Tm157 => None,
            Tm158 => None,
            Tm159 => None,
            Tm160 => None,
            Tm161 => None,
            Tm162 => None,
            Tm163 => None,
            Tm164 => None,
            Tm165 => None,
            Tm166 => None,
            Tm167 => None,
            Tm168 => None,
            Tm169 => pct!(100.0),
            Tm170 => None,
            Tm171 => None,
            Tm172 => None,
            Tm173 => None,
            Tm174 => None,
            Tm175 => None,
            Tm176 => None,
            Tm177 => None,
            Tm178 => None,
            Tm179 => None,
            Tm180 => None,
            Tm181 => None,
            Tm182 => None,
            Yb148 => None,
            Yb149 => None,
            Yb150 => None,
            Yb151 => None,
            Yb152 => None,
            Yb153 => None,
            Yb154 => None,
            Yb155 => None,
            Yb156 => None,
            Yb157 => None,
            Yb158 => None,
            Yb159 => None,
            Yb160 => None,
            Yb161 => None,
            Yb162 => None,
            Yb163 => None,
            Yb164 => None,
            Yb165 => None,
            Yb166 => None,
            Yb167 => None,
            Yb168 => pct!(0.123),
            Yb169 => None,
            Yb170 => pct!(2.982),
            Yb171 => pct!(14.086),
            Yb172 => pct!(21.686),
            Yb173 => pct!(16.103),
            Yb174 => pct!(32.025),
            Yb175 => None,
            Yb176 => pct!(12.995),
            Yb177 => None,
            Yb178 => None,
            Yb179 => None,
            Yb180 => None,
            Yb181 => None,
            Yb182 => None,
            Yb183 => None,
            Yb184 => None,
            Yb185 => None,
            Lu150 => None,
            Lu151 => None,
            Lu152 => None,
            Lu153 => None,
            Lu154 => None,
            Lu155 => None,
            Lu156 => None,
            Lu157 => None,
            Lu158 => None,
            Lu159 => None,
            Lu160 => None,
            Lu161 => None,
            Lu162 => None,
            Lu163 => None,
            Lu164 => None,
            Lu165 => None,
            Lu166 => None,
            Lu167 => None,
            Lu168 => None,
            Lu169 => None,
            Lu170 => None,
            Lu171 => None,
            Lu172 => None,
            Lu173 => None,
            Lu174 => None,
            Lu175 => pct!(97.401),
            Lu176 => pct!(2.599),
            Lu177 => None,
            Lu178 => None,
            Lu179 => None,
            Lu180 => None,
            Lu181 => None,
            Lu182 => None,
            Lu183 => None,
            Lu184 => None,
            Lu185 => None,
            Lu186 => None,
            Lu187 => None,
            Lu188 => None,
            Hf153 => None,
            Hf154 => None,
            Hf155 => None,
            Hf156 => None,
            Hf157 => None,
            Hf158 => None,
            Hf159 => None,
            Hf160 => None,
            Hf161 => None,
            Hf162 => None,
            Hf163 => None,
            Hf164 => None,
            Hf165 => None,
            Hf166 => None,
            Hf167 => None,
            Hf168 => None,
            Hf169 => None,
            Hf170 => None,
            Hf171 => None,
            Hf172 => None,
            Hf173 => None,
            Hf174 => pct!(0.16),
            Hf175 => None,
            Hf176 => pct!(5.26),
            Hf177 => pct!(18.6),
            Hf178 => pct!(27.28),
            Hf179 => pct!(13.62),
            Hf180 => pct!(35.08),
            Hf181 => None,
            Hf182 => None,
            Hf183 => None,
            Hf184 => None,
            Hf185 => None,
            Hf186 => None,
            Hf187 => None,
            Hf188 => None,
            Hf189 => None,
            Hf190 => None,
            Ta155 => None,
            Ta156 => None,
            Ta157 => None,
            Ta158 => None,
            Ta159 => None,
            Ta160 => None,
            Ta161 => None,
            Ta162 => None,
            Ta163 => None,
            Ta164 => None,
            Ta165 => None,
            Ta166 => None,
            Ta167 => None,
            Ta168 => None,
            Ta169 => None,
            Ta170 => None,
            Ta171 => None,
            Ta172 => None,
            Ta173 => None,
            Ta174 => None,
            Ta175 => None,
            Ta176 => None,
            Ta177 => None,
            Ta178 => None,
            Ta179 => None,
            Ta180 => None,
            Ta181 => pct!(99.98799),
            Ta182 => None,
            Ta183 => None,
            Ta184 => None,
            Ta185 => None,
            Ta186 => None,
            Ta187 => None,
            Ta188 => None,
            Ta189 => None,
            Ta190 => None,
            Ta191 => None,
            Ta192 => None,
            Ta193 => None,
            Ta194 => None,
            W157 => None,
            W158 => None,
            W159 => None,
            W160 => None,
            W161 => None,
            W162 => None,
            W163 => None,
            W164 => None,
            W165 => None,
            W166 => None,
            W167 => None,
            W168 => None,
            W169 => None,
            W170 => None,
            W171 => None,
            W172 => None,
            W173 => None,
            W174 => None,
            W175 => None,
            W176 => None,
            W177 => None,
            W178 => None,
            W179 => None,
            W180 => pct!(0.12),
            W181 => None,
            W182 => pct!(26.5),
            W183 => pct!(14.31),
            W184 => pct!(30.64),
            W185 => None,
            W186 => pct!(28.43),
            W187 => None,
            W188 => None,
            W189 => None,
            W190 => None,
            W191 => None,
            W192 => None,
            W193 => None,
            W194 => None,
            W195 => None,
            W196 => None,
            W197 => None,
            Re159 => None,
            Re160 => None,
            Re161 => None,
            Re162 => None,
            Re163 => None,
            Re164 => None,
            Re165 => None,
            Re166 => None,
            Re167 => None,
            Re168 => None,
            Re169 => None,
            Re170 => None,
            Re171 => None,
            Re172 => None,
            Re173 => None,
            Re174 => None,
            Re175 => None,
            Re176 => None,
            Re177 => None,
            Re178 => None,
            Re179 => None,
            Re180 => None,
            Re181 => None,
            Re182 => None,
            Re183 => None,
            Re184 => None,
            Re185 => pct!(37.4),
            Re186 => None,
            Re187 => pct!(62.6),
            Re188 => None,
            Re189 => None,
            Re190 => None,
            Re191 => None,
            Re192 => None,
            Re193 => None,
            Re194 => None,
            Re195 => None,
            Re196 => None,
            Re197 => None,
            Re198 => None,
            Re199 => None,
            Os161 => None,
            Os162 => None,
            Os163 => None,
            Os164 => None,
            Os165 => None,
            Os166 => None,
            Os167 => None,
            Os168 => None,
            Os169 => None,
            Os170 => None,
            Os171 => None,
            Os172 => None,
            Os173 => None,
            Os174 => None,
            Os175 => None,
            Os176 => None,
            Os177 => None,
            Os178 => None,
            Os179 => None,
            Os180 => None,
            Os181 => None,
            Os182 => None,
            Os183 => None,
            Os184 => pct!(0.02),
            Os185 => None,
            Os186 => pct!(1.59),
            Os187 => pct!(1.96),
            Os188 => pct!(13.24),
            Os189 => pct!(16.15),
            Os190 => pct!(26.26),
            Os191 => None,
            Os192 => pct!(40.78),
            Os193 => None,
            Os194 => None,
            Os195 => None,
            Os196 => None,
            Os197 => None,
            Os198 => None,
            Os199 => None,
            Os200 => None,
            Os201 => None,
            Os202 => None,
            Os203 => None,
            Ir163 => None,
            Ir164 => None,
            Ir165 => None,
            Ir166 => None,
            Ir167 => None,
            Ir168 => None,
            Ir169 => None,
            Ir170 => None,
            Ir171 => None,
            Ir172 => None,
            Ir173 => None,
            Ir174 => None,
            Ir175 => None,
            Ir176 => None,
            Ir177 => None,
            Ir178 => None,
            Ir179 => None,
            Ir180 => None,
            Ir181 => None,
            Ir182 => None,
            Ir183 => None,
            Ir184 => None,
            Ir185 => None,
            Ir186 => None,
            Ir187 => None,
            Ir188 => None,
            Ir189 => None,
            Ir190 => None,
            Ir191 => pct!(37.3),
            Ir192 => None,
            Ir193 => pct!(62.7),
            Ir194 => None,
            Ir195 => None,
            Ir196 => None,
            Ir197 => None,
            Ir198 => None,
            Ir199 => None,
            Ir200 => None,
            Ir201 => None,
            Ir202 => None,
            Ir203 => None,
            Ir204 => None,
            Ir205 => None,
            Pt165 => None,
            Pt166 => None,
            Pt167 => None,
            Pt168 => None,
            Pt169 => None,
            Pt170 => None,
            Pt171 => None,
            Pt172 => None,
            Pt173 => None,
            Pt174 => None,
            Pt175 => None,
            Pt176 => None,
            Pt177 => None,
            Pt178 => None,
            Pt179 => None,
            Pt180 => None,
            Pt181 => None,
            Pt182 => None,
            Pt183 => None,
            Pt184 => None,
            Pt185 => None,
            Pt186 => None,
            Pt187 => None,
            Pt188 => None,
            Pt189 => None,
            Pt190 => pct!(0.012),
            Pt191 => None,
            Pt192 => pct!(0.782),
            Pt193 => None,
            Pt194 => pct!(32.864),
            Pt195 => pct!(33.775),
            Pt196 => pct!(25.211),
            Pt197 => None,
            Pt198 => pct!(7.356),
            Pt199 => None,
            Pt200 => None,
            Pt201 => None,
            Pt202 => None,
            Pt203 => None,
            Pt204 => None,
            Pt205 => None,
            Pt206 => None,
            Pt207 => None,
            Pt208 => None,
            Au168 => None,
            Au169 => None,
            Au170 => None,
            Au171 => None,
            Au172 => None,
            Au173 => None,
            Au174 => None,
            Au175 => None,
            Au176 => None,
            Au177 => None,
            Au178 => None,
            Au179 => None,
            Au180 => None,
            Au181 => None,
            Au182 => None,
            Au183 => None,
            Au184 => None,
            Au185 => None,
            Au186 => None,
            Au187 => None,
            Au188 => None,
            Au189 => None,
            Au190 => None,
            Au191 => None,
            Au192 => None,
            Au193 => None,
            Au194 => None,
            Au195 => None,
            Au196 => None,
            Au197 => pct!(100.0),
            Au198 => None,
            Au199 => None,
            Au200 => None,
            Au201 => None,
            Au202 => None,
            Au203 => None,
            Au204 => None,
            Au205 => None,
            Au206 => None,
            Au207 => None,
            Au208 => None,
            Au209 => None,
            Au210 => None,
            Hg170 => None,
            Hg171 => None,
            Hg172 => None,
            Hg173 => None,
            Hg174 => None,
            Hg175 => None,
            Hg176 => None,
            Hg177 => None,
            Hg178 => None,
            Hg179 => None,
            Hg180 => None,
            Hg181 => None,
            Hg182 => None,
            Hg183 => None,
            Hg184 => None,
            Hg185 => None,
            Hg186 => None,
            Hg187 => None,
            Hg188 => None,
            Hg189 => None,
            Hg190 => None,
            Hg191 => None,
            Hg192 => None,
            Hg193 => None,
            Hg194 => None,
            Hg195 => None,
            Hg196 => pct!(0.15),
            Hg197 => None,
            Hg198 => pct!(10.04),
            Hg199 => pct!(16.94),
            Hg200 => pct!(23.14),
            Hg201 => pct!(13.17),
            Hg202 => pct!(29.74),
            Hg203 => None,
            Hg204 => pct!(6.82),
            Hg205 => None,
            Hg206 => None,
            Hg207 => None,
            Hg208 => None,
            Hg209 => None,
            Hg210 => None,
            Hg211 => None,
            Hg212 => None,
            Hg213 => None,
            Hg214 => None,
            Hg215 => None,
            Hg216 => None,
            Tl176 => None,
            Tl177 => None,
            Tl178 => None,
            Tl179 => None,
            Tl180 => None,
            Tl181 => None,
            Tl182 => None,
            Tl183 => None,
            Tl184 => None,
            Tl185 => None,
            Tl186 => None,
            Tl187 => None,
            Tl188 => None,
            Tl189 => None,
            Tl190 => None,
            Tl191 => None,
            Tl192 => None,
            Tl193 => None,
            Tl194 => None,
            Tl195 => None,
            Tl196 => None,
            Tl197 => None,
            Tl198 => None,
            Tl199 => None,
            Tl200 => None,
            Tl201 => None,
            Tl202 => None,
            Tl203 => pct!(29.515),
            Tl204 => None,
            Tl205 => pct!(70.485),
            Tl206 => None,
            Tl207 => None,
            Tl208 => None,
            Tl209 => None,
            Tl210 => None,
            Tl211 => None,
            Tl212 => None,
            Tl213 => None,
            Tl214 => None,
            Tl215 => None,
            Tl216 => None,
            Tl217 => None,
            Tl218 => None,
            Pb178 => None,
            Pb179 => None,
            Pb180 => None,
            Pb181 => None,
            Pb182 => None,
            Pb183 => None,
            Pb184 => None,
            Pb185 => None,
            Pb186 => None,
            Pb187 => None,
            Pb188 => None,
            Pb189 => None,
            Pb190 => None,
            Pb191 => None,
            Pb192 => None,
            Pb193 => None,
            Pb194 => None,
            Pb195 => None,
            Pb196 => None,
            Pb197 => None,
            Pb198 => None,
            Pb199 => None,
            Pb200 => None,
            Pb201 => None,
            Pb202 => None,
            Pb203 => None,
            Pb204 => pct!(1.4),
            Pb205 => None,
            Pb206 => pct!(24.1),
            Pb207 => pct!(22.1),
            Pb208 => pct!(52.4),
            Pb209 => None,
            Pb210 => None,
            Pb211 => None,
            Pb212 => None,
            Pb213 => None,
            Pb214 => None,
            Pb215 => None,
            Pb216 => None,
            Pb217 => None,
            Pb218 => None,
            Pb219 => None,
            Pb220 => None,
            Bi184 => None,
            Bi185 => None,
            Bi186 => None,
            Bi187 => None,
            Bi188 => None,
            Bi189 => None,
            Bi190 => None,
            Bi191 => None,
            Bi192 => None,
            Bi193 => None,
            Bi194 => None,
            Bi195 => None,
            Bi196 => None,
            Bi197 => None,
            Bi198 => None,
            Bi199 => None,
            Bi200 => None,
            Bi201 => None,
            Bi202 => None,
            Bi203 => None,
            Bi204 => None,
            Bi205 => None,
            Bi206 => None,
            Bi207 => None,
            Bi208 => None,
            Bi209 => pct!(100.0),
            Bi210 => None,
            Bi211 => None,
            Bi212 => None,
            Bi213 => None,
            Bi214 => None,
            Bi215 => None,
            Bi216 => None,
            Bi217 => None,
            Bi218 => None,
            Bi219 => None,
            Bi220 => None,
            Bi221 => None,
            Bi222 => None,
            Bi223 => None,
            Bi224 => None,
            Po186 => None,
            Po187 => None,
            Po188 => None,
            Po189 => None,
            Po190 => None,
            Po191 => None,
            Po192 => None,
            Po193 => None,
            Po194 => None,
            Po195 => None,
            Po196 => None,
            Po197 => None,
            Po198 => None,
            Po199 => None,
            Po200 => None,
            Po201 => None,
            Po202 => None,
            Po203 => None,
            Po204 => None,
            Po205 => None,
            Po206 => None,
            Po207 => None,
            Po208 => None,
            Po209 => None,
            Po210 => None,
            Po211 => None,
            Po212 => None,
            Po213 => None,
            Po214 => None,
            Po215 => None,
            Po216 => None,
            Po217 => None,
            Po218 => None,
            Po219 => None,
            Po220 => None,
            Po221 => None,
            Po222 => None,
            Po223 => None,
            Po224 => None,
            Po225 => None,
            Po226 => None,
            Po227 => None,
            At191 => None,
            At192 => None,
            At193 => None,
            At194 => None,
            At195 => None,
            At196 => None,
            At197 => None,
            At198 => None,
            At199 => None,
            At200 => None,
            At201 => None,
            At202 => None,
            At203 => None,
            At204 => None,
            At205 => None,
            At206 => None,
            At207 => None,
            At208 => None,
            At209 => None,
            At210 => None,
            At211 => None,
            At212 => None,
            At213 => None,
            At214 => None,
            At215 => None,
            At216 => None,
            At217 => None,
            At218 => None,
            At219 => None,
            At220 => None,
            At221 => None,
            At222 => None,
            At223 => None,
            At224 => None,
            At225 => None,
            At226 => None,
            At227 => None,
            At228 => None,
            At229 => None,
            Rn193 => None,
            Rn194 => None,
            Rn195 => None,
            Rn196 => None,
            Rn197 => None,
            Rn198 => None,
            Rn199 => None,
            Rn200 => None,
            Rn201 => None,
            Rn202 => None,
            Rn203 => None,
            Rn204 => None,
            Rn205 => None,
            Rn206 => None,
            Rn207 => None,
            Rn208 => None,
            Rn209 => None,
            Rn210 => None,
            Rn211 => None,
            Rn212 => None,
            Rn213 => None,
            Rn214 => None,
            Rn215 => None,
            Rn216 => None,
            Rn217 => None,
            Rn218 => None,
            Rn219 => None,
            Rn220 => None,
            Rn221 => None,
            Rn222 => None,
            Rn223 => None,
            Rn224 => None,
            Rn225 => None,
            Rn226 => None,
            Rn227 => None,
            Rn228 => None,
            Rn229 => None,
            Rn230 => None,
            Rn231 => None,
            Fr197 => None,
            Fr198 => None,
            Fr199 => None,
            Fr200 => None,
            Fr201 => None,
            Fr202 => None,
            Fr203 => None,
            Fr204 => None,
            Fr205 => None,
            Fr206 => None,
            Fr207 => None,
            Fr208 => None,
            Fr209 => None,
            Fr210 => None,
            Fr211 => None,
            Fr212 => None,
            Fr213 => None,
            Fr214 => None,
            Fr215 => None,
            Fr216 => None,
            Fr217 => None,
            Fr218 => None,
            Fr219 => None,
            Fr220 => None,
            Fr221 => None,
            Fr222 => None,
            Fr223 => None,
            Fr224 => None,
            Fr225 => None,
            Fr226 => None,
            Fr227 => None,
            Fr228 => None,
            Fr229 => None,
            Fr230 => None,
            Fr231 => None,
            Fr232 => None,
            Fr233 => None,
            Ra201 => None,
            Ra202 => None,
            Ra203 => None,
            Ra204 => None,
            Ra205 => None,
            Ra206 => None,
            Ra207 => None,
            Ra208 => None,
            Ra209 => None,
            Ra210 => None,
            Ra211 => None,
            Ra212 => None,
            Ra213 => None,
            Ra214 => None,
            Ra215 => None,
            Ra216 => None,
            Ra217 => None,
            Ra218 => None,
            Ra219 => None,
            Ra220 => None,
            Ra221 => None,
            Ra222 => None,
            Ra223 => None,
            Ra224 => None,
            Ra225 => None,
            Ra226 => None,
            Ra227 => None,
            Ra228 => None,
            Ra229 => None,
            Ra230 => None,
            Ra231 => None,
            Ra232 => None,
            Ra233 => None,
            Ra234 => None,
            Ra235 => None,
            Ac205 => None,
            Ac206 => None,
            Ac207 => None,
            Ac208 => None,
            Ac209 => None,
            Ac210 => None,
            Ac211 => None,
            Ac212 => None,
            Ac213 => None,
            Ac214 => None,
            Ac215 => None,
            Ac216 => None,
            Ac217 => None,
            Ac218 => None,
            Ac219 => None,
            Ac220 => None,
            Ac221 => None,
            Ac222 => None,
            Ac223 => None,
            Ac224 => None,
            Ac225 => None,
            Ac226 => None,
            Ac227 => None,
            Ac228 => None,
            Ac229 => None,
            Ac230 => None,
            Ac231 => None,
            Ac232 => None,
            Ac233 => None,
            Ac234 => None,
            Ac235 => None,
            Ac236 => None,
            Ac237 => None,
            Th208 => None,
            Th209 => None,
            Th210 => None,
            Th211 => None,
            Th212 => None,
            Th213 => None,
            Th214 => None,
            Th215 => None,
            Th216 => None,
            Th217 => None,
            Th218 => None,
            Th219 => None,
            Th220 => None,
            Th221 => None,
            Th222 => None,
            Th223 => None,
            Th224 => None,
            Th225 => None,
            Th226 => None,
            Th227 => None,
            Th228 => None,
            Th229 => None,
            Th230 => pct!(0.02),
            Th231 => None,
            Th232 => pct!(99.98),
            Th233 => None,
            Th234 => None,
            Th235 => None,
            Th236 => None,
            Th237 => None,
            Th238 => None,
            Th239 => None,
            Pa211 => None,
            Pa212 => None,
            Pa213 => None,
            Pa214 => None,
            Pa215 => None,
            Pa216 => None,
            Pa217 => None,
            Pa218 => None,
            Pa219 => None,
            Pa220 => None,
            Pa221 => None,
            Pa222 => None,
            Pa223 => None,
            Pa224 => None,
            Pa225 => None,
            Pa226 => None,
            Pa227 => None,
            Pa228 => None,
            Pa229 => None,
            Pa230 => None,
            Pa231 => pct!(100.0),
            Pa232 => None,
            Pa233 => None,
            Pa234 => None,
            Pa235 => None,
            Pa236 => None,
            Pa237 => None,
            Pa238 => None,
            Pa239 => None,
            Pa240 => None,
            Pa241 => None,
            U215 => None,
            U216 => None,
            U217 => None,
            U218 => None,
            U219 => None,
            U220 => None,
            U221 => None,
            U222 => None,
            U223 => None,
            U224 => None,
            U225 => None,
            U226 => None,
            U227 => None,
            U228 => None,
            U229 => None,
            U230 => None,
            U231 => None,
            U232 => None,
            U233 => None,
            U234 => pct!(0.0054),
            U235 => pct!(0.7204),
            U236 => None,
            U237 => None,
            U238 => pct!(99.2742),
            U239 => None,
            U240 => None,
            U241 => None,
            U242 => None,
            U243 => None,
            Np219 => None,
            Np220 => None,
            Np221 => None,
            Np222 => None,
            Np223 => None,
            Np224 => None,
            Np225 => None,
            Np226 => None,
            Np227 => None,
            Np228 => None,
            Np229 => None,
            Np230 => None,
            Np231 => None,
            Np232 => None,
            Np233 => None,
            Np234 => None,
            Np235 => None,
            Np236 => None,
            Np237 => None,
            Np238 => None,
            Np239 => None,
            Np240 => None,
            Np241 => None,
            Np242 => None,
            Np243 => None,
            Np244 => None,
            Np245 => None,
            Pu221 => None,
            Pu222 => None,
            Pu223 => None,
            Pu224 => None,
            Pu225 => None,
            Pu226 => None,
            Pu227 => None,
            Pu228 => None,
            Pu229 => None,
            Pu230 => None,
            Pu231 => None,
            Pu232 => None,
            Pu233 => None,
            Pu234 => None,
            Pu235 => None,
            Pu236 => None,
            Pu237 => None,
            Pu238 => None,
            Pu239 => None,
            Pu240 => None,
            Pu241 => None,
            Pu242 => None,
            Pu243 => None,
            Pu244 => None,
            Pu245 => None,
            Pu246 => None,
            Pu247 => None,
            Am223 => None,
            Am224 => None,
            Am225 => None,
            Am226 => None,
            Am227 => None,
            Am228 => None,
            Am229 => None,
            Am230 => None,
            Am231 => None,
            Am232 => None,
            Am233 => None,
            Am234 => None,
            Am235 => None,
            Am236 => None,
            Am237 => None,
            Am238 => None,
            Am239 => None,
            Am240 => None,
            Am241 => None,
            Am242 => None,
            Am243 => None,
            Am244 => None,
            Am245 => None,
            Am246 => None,
            Am247 => None,
            Am248 => None,
            Am249 => None,
            Cm231 => None,
            Cm232 => None,
            Cm233 => None,
            Cm234 => None,
            Cm235 => None,
            Cm236 => None,
            Cm237 => None,
            Cm238 => None,
            Cm239 => None,
            Cm240 => None,
            Cm241 => None,
            Cm242 => None,
            Cm243 => None,
            Cm244 => None,
            Cm245 => None,
            Cm246 => None,
            Cm247 => None,
            Cm248 => None,
            Cm249 => None,
            Cm250 => None,
            Cm251 => None,
            Cm252 => None,
            Bk233 => None,
            Bk234 => None,
            Bk235 => None,
            Bk236 => None,
            Bk237 => None,
            Bk238 => None,
            Bk239 => None,
            Bk240 => None,
            Bk241 => None,
            Bk242 => None,
            Bk243 => None,
            Bk244 => None,
            Bk245 => None,
            Bk246 => None,
            Bk247 => None,
            Bk248 => None,
            Bk249 => None,
            Bk250 => None,
            Bk251 => None,
            Bk252 => None,
            Bk253 => None,
            Bk254 => None,
            Cf237 => None,
            Cf238 => None,
            Cf239 => None,
            Cf240 => None,
            Cf241 => None,
            Cf242 => None,
            Cf243 => None,
            Cf244 => None,
            Cf245 => None,
            Cf246 => None,
            Cf247 => None,
            Cf248 => None,
            Cf249 => None,
            Cf250 => None,
            Cf251 => None,
            Cf252 => None,
            Cf253 => None,
            Cf254 => None,
            Cf255 => None,
            Cf256 => None,
            Es239 => None,
            Es240 => None,
            Es241 => None,
            Es242 => None,
            Es243 => None,
            Es244 => None,
            Es245 => None,
            Es246 => None,
            Es247 => None,
            Es248 => None,
            Es249 => None,
            Es250 => None,
            Es251 => None,
            Es252 => None,
            Es253 => None,
            Es254 => None,
            Es255 => None,
            Es256 => None,
            Es257 => None,
            Es258 => None,
            Fm241 => None,
            Fm242 => None,
            Fm243 => None,
            Fm244 => None,
            Fm245 => None,
            Fm246 => None,
            Fm247 => None,
            Fm248 => None,
            Fm249 => None,
            Fm250 => None,
            Fm251 => None,
            Fm252 => None,
            Fm253 => None,
            Fm254 => None,
            Fm255 => None,
            Fm256 => None,
            Fm257 => None,
            Fm258 => None,
            Fm259 => None,
            Fm260 => None,
            Md244 => None,
            Md245 => None,
            Md246 => None,
            Md247 => None,
            Md248 => None,
            Md249 => None,
            Md250 => None,
            Md251 => None,
            Md252 => None,
            Md253 => None,
            Md254 => None,
            Md255 => None,
            Md256 => None,
            Md257 => None,
            Md258 => None,
            Md259 => None,
            Md260 => None,
            Md261 => None,
            Md262 => None,
            No248 => None,
            No249 => None,
            No250 => None,
            No251 => None,
            No252 => None,
            No253 => None,
            No254 => None,
            No255 => None,
            No256 => None,
            No257 => None,
            No258 => None,
            No259 => None,
            No260 => None,
            No261 => None,
            No262 => None,
            No263 => None,
            No264 => None,
            Lr251 => None,
            Lr252 => None,
            Lr253 => None,
            Lr254 => None,
            Lr255 => None,
            Lr256 => None,
            Lr257 => None,
            Lr258 => None,
            Lr259 => None,
            Lr260 => None,
            Lr261 => None,
            Lr262 => None,
            Lr263 => None,
            Lr264 => None,
            Lr265 => None,
            Lr266 => None,
            Rf253 => None,
            Rf254 => None,
            Rf255 => None,
            Rf256 => None,
            Rf257 => None,
            Rf258 => None,
            Rf259 => None,
            Rf260 => None,
            Rf261 => None,
            Rf262 => None,
            Rf263 => None,
            Rf264 => None,
            Rf265 => None,
            Rf266 => None,
            Rf267 => None,
            Rf268 => None,
            Db255 => None,
            Db256 => None,
            Db257 => None,
            Db258 => None,
            Db259 => None,
            Db260 => None,
            Db261 => None,
            Db262 => None,
            Db263 => None,
            Db264 => None,
            Db265 => None,
            Db266 => None,
            Db267 => None,
            Db268 => None,
            Db269 => None,
            Db270 => None,
            Sg258 => None,
            Sg259 => None,
            Sg260 => None,
            Sg261 => None,
            Sg262 => None,
            Sg263 => None,
            Sg264 => None,
            Sg265 => None,
            Sg266 => None,
            Sg267 => None,
            Sg268 => None,
            Sg269 => None,
            Sg270 => None,
            Sg271 => None,
            Sg272 => None,
            Sg273 => None,
            Bh260 => None,
            Bh261 => None,
            Bh262 => None,
            Bh263 => None,
            Bh264 => None,
            Bh265 => None,
            Bh266 => None,
            Bh267 => None,
            Bh268 => None,
            Bh269 => None,
            Bh270 => None,
            Bh271 => None,
            Bh272 => None,
            Bh273 => None,
            Bh274 => None,
            Bh275 => None,
            Bh276 => None,
            Bh277 => None,
            Bh278 => None,
            Hs263 => None,
            Hs264 => None,
            Hs265 => None,
            Hs266 => None,
            Hs267 => None,
            Hs268 => None,
            Hs269 => None,
            Hs270 => None,
            Hs271 => None,
            Hs272 => None,
            Hs273 => None,
            Hs274 => None,
            Hs275 => None,
            Hs276 => None,
            Hs277 => None,
            Hs278 => None,
            Hs279 => None,
            Hs280 => None,
            Mt265 => None,
            Mt266 => None,
            Mt267 => None,
            Mt268 => None,
            Mt269 => None,
            Mt270 => None,
            Mt271 => None,
            Mt272 => None,
            Mt273 => None,
            Mt274 => None,
            Mt275 => None,
            Mt276 => None,
            Mt277 => None,
            Mt278 => None,
            Mt279 => None,
            Mt280 => None,
            Mt281 => None,
            Mt282 => None,
            Ds267 => None,
            Ds268 => None,
            Ds269 => None,
            Ds270 => None,
            Ds271 => None,
            Ds272 => None,
            Ds273 => None,
            Ds274 => None,
            Ds275 => None,
            Ds276 => None,
            Ds277 => None,
            Ds278 => None,
            Ds279 => None,
            Ds280 => None,
            Ds281 => None,
            Ds282 => None,
            Ds283 => None,
            Ds284 => None,
            Rg272 => None,
            Rg273 => None,
            Rg274 => None,
            Rg275 => None,
            Rg276 => None,
            Rg277 => None,
            Rg278 => None,
            Rg279 => None,
            Rg280 => None,
            Rg281 => None,
            Rg282 => None,
            Rg283 => None,
            Rg284 => None,
            Rg285 => None,
            Rg286 => None,
            Cn276 => None,
            Cn277 => None,
            Cn278 => None,
            Cn279 => None,
            Cn280 => None,
            Cn281 => None,
            Cn282 => None,
            Cn283 => None,
            Cn284 => None,
            Cn285 => None,
            Cn286 => None,
            Cn287 => None,
            Cn288 => None,
            Nh278 => None,
            Nh279 => None,
            Nh280 => None,
            Nh281 => None,
            Nh282 => None,
            Nh283 => None,
            Nh284 => None,
            Nh285 => None,
            Nh286 => None,
            Nh287 => None,
            Nh288 => None,
            Nh289 => None,
            Nh290 => None,
            Fl284 => None,
            Fl285 => None,
            Fl286 => None,
            Fl287 => None,
            Fl288 => None,
            Fl289 => None,
            Fl290 => None,
            Fl291 => None,
            Mc287 => None,
            Mc288 => None,
            Mc289 => None,
            Mc290 => None,
            Mc291 => None,
            Mc292 => None,
            Lv289 => None,
            Lv290 => None,
            Lv291 => None,
            Lv292 => None,
            Lv293 => None,
            Ts291 => None,
            Ts292 => None,
            Ts293 => None,
            Ts294 => None,
            Og293 => None,
            Og294 => None,
            Og295 => None,
        }
    }
}
