use super::Element;
use super::Element::*;

#[derive(Clone, Copy, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
/// The category of the oxidation state, to distinguish common and uncommon states
pub enum OxidationStateCategory {
    /// Most common oxidation states
    Main,
    /// Less common oxidation states that are observed under specific conditions
    Extended,
    /// All oxidation states, i.e., Main + Extended
    All,
}

impl Element {
    /// Returns the element's oxidation states for the given `category`.
    ///
    /// # Example
    /// ```rust
    /// use mendeleev::{Element, OxidationStateCategory::{Main, Extended, All}};
    ///
    /// assert_eq!(Element::N.oxidation_states(Main), [-3, 3, 5]);
    /// assert_eq!(Element::N.oxidation_states(Extended), [-2, -1, 0, 1, 2, 4]);
    /// assert_eq!(Element::N.oxidation_states(All), [-3, -2, -1, 0, 1, 2, 3, 4, 5]);
    /// ```
    pub const fn oxidation_states(&self, category: OxidationStateCategory) -> &'static [i8] {
        use OxidationStateCategory::*;
        match (self, category) {
            (H, Main) => &[-1, 1],
            (H, Extended) => &[],
            (H, All) => &[-1, 1],
            (He, Main) => &[],
            (He, Extended) => &[],
            (He, All) => &[],
            (Li, Main) => &[1],
            (Li, Extended) => &[0],
            (Li, All) => &[0, 1],
            (Be, Main) => &[2],
            (Be, Extended) => &[0, 1],
            (Be, All) => &[0, 1, 2],
            (B, Main) => &[3],
            (B, Extended) => &[-5, -1, 0, 1, 2],
            (B, All) => &[-5, -1, 0, 1, 2, 3],
            (C, Main) => &[-4, -3, -2, -1, 0, 1, 2, 3, 4],
            (C, Extended) => &[],
            (C, All) => &[-4, -3, -2, -1, 0, 1, 2, 3, 4],
            (N, Main) => &[-3, 3, 5],
            (N, Extended) => &[-2, -1, 0, 1, 2, 4],
            (N, All) => &[-3, -2, -1, 0, 1, 2, 3, 4, 5],
            (O, Main) => &[-2],
            (O, Extended) => &[-1, 0, 1, 2],
            (O, All) => &[-2, -1, 0, 1, 2],
            (F, Main) => &[-1],
            (F, Extended) => &[0],
            (F, All) => &[-1, 0],
            (Ne, Main) => &[],
            (Ne, Extended) => &[],
            (Ne, All) => &[],
            (Na, Main) => &[1],
            (Na, Extended) => &[-1, 0],
            (Na, All) => &[-1, 0, 1],
            (Mg, Main) => &[2],
            (Mg, Extended) => &[0, 1],
            (Mg, All) => &[0, 1, 2],
            (Al, Main) => &[3],
            (Al, Extended) => &[-2, -1, 0, 1, 2],
            (Al, All) => &[-2, -1, 0, 1, 2, 3],
            (Si, Main) => &[-4, 4],
            (Si, Extended) => &[-3, -2, -1, 0, 1, 2, 3],
            (Si, All) => &[-4, -3, -2, -1, 0, 1, 2, 3, 4],
            (P, Main) => &[-3, 3, 5],
            (P, Extended) => &[-2, -1, 0, 1, 2, 4],
            (P, All) => &[-3, -2, -1, 0, 1, 2, 3, 4, 5],
            (S, Main) => &[-2, 2, 4, 6],
            (S, Extended) => &[-1, 0, 1, 3, 5],
            (S, All) => &[-2, -1, 0, 1, 2, 3, 4, 5, 6],
            (Cl, Main) => &[-1, 1, 3, 5, 7],
            (Cl, Extended) => &[2, 4, 6],
            (Cl, All) => &[-1, 1, 2, 3, 4, 5, 6, 7],
            (Ar, Main) => &[0],
            (Ar, Extended) => &[],
            (Ar, All) => &[0],
            (K, Main) => &[1],
            (K, Extended) => &[-1],
            (K, All) => &[-1, 1],
            (Ca, Main) => &[2],
            (Ca, Extended) => &[1],
            (Ca, All) => &[1, 2],
            (Sc, Main) => &[3],
            (Sc, Extended) => &[0, 1, 2],
            (Sc, All) => &[0, 1, 2, 3],
            (Ti, Main) => &[2, 3, 4],
            (Ti, Extended) => &[-2, -1, 0, 1],
            (Ti, All) => &[-2, -1, 0, 1, 2, 3, 4],
            (V, Main) => &[2, 3, 4, 5],
            (V, Extended) => &[-3, -1, 0, 1],
            (V, All) => &[-3, -1, 0, 1, 2, 3, 4, 5],
            (Cr, Main) => &[2, 3, 6],
            (Cr, Extended) => &[-4, -2, -1, 0, 1, 4, 5],
            (Cr, All) => &[-4, -2, -1, 0, 1, 2, 3, 4, 5, 6],
            (Mn, Main) => &[2, 3, 4, 6, 7],
            (Mn, Extended) => &[-3, -2, -1, 0, 1, 5],
            (Mn, All) => &[-3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7],
            (Fe, Main) => &[2, 3],
            (Fe, Extended) => &[-4, -2, -1, 0, 1, 4, 5, 6, 7],
            (Fe, All) => &[-4, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7],
            (Co, Main) => &[2, 3],
            (Co, Extended) => &[-3, -1, 0, 1, 4, 5],
            (Co, All) => &[-3, -1, 0, 1, 2, 3, 4, 5],
            (Ni, Main) => &[2],
            (Ni, Extended) => &[-2, -1, 0, 1, 3, 4],
            (Ni, All) => &[-2, -1, 0, 1, 2, 3, 4],
            (Cu, Main) => &[1, 2],
            (Cu, Extended) => &[-2, 0, 3, 4],
            (Cu, All) => &[-2, 0, 1, 2, 3, 4],
            (Zn, Main) => &[2],
            (Zn, Extended) => &[-2, 0, 1],
            (Zn, All) => &[-2, 0, 1, 2],
            (Ga, Main) => &[3],
            (Ga, Extended) => &[-5, -4, -3, -2, -1, 0, 1, 2],
            (Ga, All) => &[-5, -4, -3, -2, -1, 0, 1, 2, 3],
            (Ge, Main) => &[-4, 2, 4],
            (Ge, Extended) => &[-3, -2, -1, 0, 1, 3],
            (Ge, All) => &[-4, -3, -2, -1, 0, 1, 2, 3, 4],
            (As, Main) => &[-3, 3, 5],
            (As, Extended) => &[-2, -1, 0, 1, 2, 4],
            (As, All) => &[-3, -2, -1, 0, 1, 2, 3, 4, 5],
            (Se, Main) => &[-2, 2, 4, 6],
            (Se, Extended) => &[-1, 0, 1, 3, 5],
            (Se, All) => &[-2, -1, 0, 1, 2, 3, 4, 5, 6],
            (Br, Main) => &[-1, 1, 3, 5],
            (Br, Extended) => &[2, 4, 7],
            (Br, All) => &[-1, 1, 2, 3, 4, 5, 7],
            (Kr, Main) => &[0],
            (Kr, Extended) => &[1, 2],
            (Kr, All) => &[0, 1, 2],
            (Rb, Main) => &[1],
            (Rb, Extended) => &[-1],
            (Rb, All) => &[-1, 1],
            (Sr, Main) => &[2],
            (Sr, Extended) => &[1],
            (Sr, All) => &[1, 2],
            (Y, Main) => &[3],
            (Y, Extended) => &[0, 1, 2],
            (Y, All) => &[0, 1, 2, 3],
            (Zr, Main) => &[4],
            (Zr, Extended) => &[-2, 0, 1, 2, 3],
            (Zr, All) => &[-2, 0, 1, 2, 3, 4],
            (Nb, Main) => &[5],
            (Nb, Extended) => &[-3, -1, 0, 1, 2, 3, 4],
            (Nb, All) => &[-3, -1, 0, 1, 2, 3, 4, 5],
            (Mo, Main) => &[4, 6],
            (Mo, Extended) => &[-4, -2, -1, 0, 1, 2, 3, 5],
            (Mo, All) => &[-4, -2, -1, 0, 1, 2, 3, 4, 5, 6],
            (Tc, Main) => &[4, 7],
            (Tc, Extended) => &[-3, -1, 0, 1, 2, 3, 5, 6],
            (Tc, All) => &[-3, -1, 0, 1, 2, 3, 4, 5, 6, 7],
            (Ru, Main) => &[3, 4],
            (Ru, Extended) => &[-4, -2, 0, 1, 2, 5, 6, 7, 8],
            (Ru, All) => &[-4, -2, 0, 1, 2, 3, 4, 5, 6, 7, 8],
            (Rh, Main) => &[3],
            (Rh, Extended) => &[-3, -1, 0, 1, 2, 4, 5, 6, 7],
            (Rh, All) => &[-3, -1, 0, 1, 2, 3, 4, 5, 6, 7],
            (Pd, Main) => &[0, 2, 4],
            (Pd, Extended) => &[1, 3, 5],
            (Pd, All) => &[0, 1, 2, 3, 4, 5],
            (Ag, Main) => &[1],
            (Ag, Extended) => &[-2, -1, 0, 2, 3],
            (Ag, All) => &[-2, -1, 0, 1, 2, 3],
            (Cd, Main) => &[2],
            (Cd, Extended) => &[-2, 1],
            (Cd, All) => &[-2, 1, 2],
            (In, Main) => &[3],
            (In, Extended) => &[-5, -2, -1, 0, 1, 2],
            (In, All) => &[-5, -2, -1, 0, 1, 2, 3],
            (Sn, Main) => &[-4, 2, 4],
            (Sn, Extended) => &[-3, -2, -1, 0, 1, 3],
            (Sn, All) => &[-4, -3, -2, -1, 0, 1, 2, 3, 4],
            (Sb, Main) => &[-3, 3, 5],
            (Sb, Extended) => &[-2, -1, 0, 1, 2, 4],
            (Sb, All) => &[-3, -2, -1, 0, 1, 2, 3, 4, 5],
            (Te, Main) => &[-2, 2, 4, 6],
            (Te, Extended) => &[-1, 0, 1, 3, 5],
            (Te, All) => &[-2, -1, 0, 1, 2, 3, 4, 5, 6],
            (I, Main) => &[-1, 1, 3, 5, 7],
            (I, Extended) => &[2, 4, 6],
            (I, All) => &[-1, 1, 2, 3, 4, 5, 6, 7],
            (Xe, Main) => &[0],
            (Xe, Extended) => &[2, 4, 6, 8],
            (Xe, All) => &[0, 2, 4, 6, 8],
            (Cs, Main) => &[1],
            (Cs, Extended) => &[-1],
            (Cs, All) => &[-1, 1],
            (Ba, Main) => &[2],
            (Ba, Extended) => &[1],
            (Ba, All) => &[1, 2],
            (La, Main) => &[3],
            (La, Extended) => &[0, 1, 2],
            (La, All) => &[0, 1, 2, 3],
            (Ce, Main) => &[3, 4],
            (Ce, Extended) => &[2],
            (Ce, All) => &[2, 3, 4],
            (Pr, Main) => &[3],
            (Pr, Extended) => &[0, 1, 2, 4, 5],
            (Pr, All) => &[0, 1, 2, 3, 4, 5],
            (Nd, Main) => &[3],
            (Nd, Extended) => &[0, 2, 4],
            (Nd, All) => &[0, 2, 3, 4],
            (Pm, Main) => &[3],
            (Pm, Extended) => &[2],
            (Pm, All) => &[2, 3],
            (Sm, Main) => &[3],
            (Sm, Extended) => &[0, 1, 2],
            (Sm, All) => &[0, 1, 2, 3],
            (Eu, Main) => &[2, 3],
            (Eu, Extended) => &[0],
            (Eu, All) => &[0, 2, 3],
            (Gd, Main) => &[3],
            (Gd, Extended) => &[0, 1, 2],
            (Gd, All) => &[0, 1, 2, 3],
            (Tb, Main) => &[3],
            (Tb, Extended) => &[0, 1, 2, 4],
            (Tb, All) => &[0, 1, 2, 3, 4],
            (Dy, Main) => &[3],
            (Dy, Extended) => &[0, 2, 4],
            (Dy, All) => &[0, 2, 3, 4],
            (Ho, Main) => &[3],
            (Ho, Extended) => &[0, 2],
            (Ho, All) => &[0, 2, 3],
            (Er, Main) => &[3],
            (Er, Extended) => &[0, 2],
            (Er, All) => &[0, 2, 3],
            (Tm, Main) => &[3],
            (Tm, Extended) => &[0, 1, 2],
            (Tm, All) => &[0, 1, 2, 3],
            (Yb, Main) => &[3],
            (Yb, Extended) => &[0, 1, 2],
            (Yb, All) => &[0, 1, 2, 3],
            (Lu, Main) => &[3],
            (Lu, Extended) => &[0, 2],
            (Lu, All) => &[0, 2, 3],
            (Hf, Main) => &[4],
            (Hf, Extended) => &[-2, 0, 1, 2, 3],
            (Hf, All) => &[-2, 0, 1, 2, 3, 4],
            (Ta, Main) => &[5],
            (Ta, Extended) => &[-3, -1, 0, 1, 2, 3, 4],
            (Ta, All) => &[-3, -1, 0, 1, 2, 3, 4, 5],
            (W, Main) => &[4, 6],
            (W, Extended) => &[-4, -2, -1, 0, 1, 2, 3, 5],
            (W, All) => &[-4, -2, -1, 0, 1, 2, 3, 4, 5, 6],
            (Re, Main) => &[4, 7],
            (Re, Extended) => &[-3, -1, 0, 1, 2, 3, 5, 6],
            (Re, All) => &[-3, -1, 0, 1, 2, 3, 4, 5, 6, 7],
            (Os, Main) => &[4],
            (Os, Extended) => &[-4, -2, -1, 0, 1, 2, 3, 5, 6, 7, 8],
            (Os, All) => &[-4, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8],
            (Ir, Main) => &[3, 4],
            (Ir, Extended) => &[-3, -1, 0, 1, 2, 5, 6, 7, 8, 9],
            (Ir, All) => &[-3, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9],
            (Pt, Main) => &[2, 4],
            (Pt, Extended) => &[-3, -2, -1, 0, 1, 3, 5, 6],
            (Pt, All) => &[-3, -2, -1, 0, 1, 2, 3, 4, 5, 6],
            (Au, Main) => &[1, 3],
            (Au, Extended) => &[-3, -2, -1, 0, 2, 5],
            (Au, All) => &[-3, -2, -1, 0, 1, 2, 3, 5],
            (Hg, Main) => &[1, 2],
            (Hg, Extended) => &[-2],
            (Hg, All) => &[-2, 1, 2],
            (Tl, Main) => &[1, 3],
            (Tl, Extended) => &[-5, -2, -1, 2],
            (Tl, All) => &[-5, -2, -1, 1, 2, 3],
            (Pb, Main) => &[2, 4],
            (Pb, Extended) => &[-4, -2, -1, 0, 1, 3],
            (Pb, All) => &[-4, -2, -1, 0, 1, 2, 3, 4],
            (Bi, Main) => &[3],
            (Bi, Extended) => &[-3, -2, -1, 0, 1, 2, 4, 5],
            (Bi, All) => &[-3, -2, -1, 0, 1, 2, 3, 4, 5],
            (Po, Main) => &[-2, 2, 4],
            (Po, Extended) => &[5, 6],
            (Po, All) => &[-2, 2, 4, 5, 6],
            (At, Main) => &[-1, 1],
            (At, Extended) => &[3, 5, 7],
            (At, All) => &[-1, 1, 3, 5, 7],
            (Rn, Main) => &[2],
            (Rn, Extended) => &[6],
            (Rn, All) => &[2, 6],
            (Fr, Main) => &[1],
            (Fr, Extended) => &[],
            (Fr, All) => &[1],
            (Ra, Main) => &[2],
            (Ra, Extended) => &[],
            (Ra, All) => &[2],
            (Ac, Main) => &[3],
            (Ac, Extended) => &[2],
            (Ac, All) => &[2, 3],
            (Th, Main) => &[4],
            (Th, Extended) => &[-1, 1, 2, 3],
            (Th, All) => &[-1, 1, 2, 3, 4],
            (Pa, Main) => &[5],
            (Pa, Extended) => &[2, 3, 4],
            (Pa, All) => &[2, 3, 4, 5],
            (U, Main) => &[4, 6],
            (U, Extended) => &[-1, 1, 2, 3, 5],
            (U, All) => &[-1, 1, 2, 3, 4, 5, 6],
            (Np, Main) => &[5],
            (Np, Extended) => &[2, 3, 4, 6, 7],
            (Np, All) => &[2, 3, 4, 5, 6, 7],
            (Pu, Main) => &[4],
            (Pu, Extended) => &[2, 3, 5, 6, 7, 8],
            (Pu, All) => &[2, 3, 4, 5, 6, 7, 8],
            (Am, Main) => &[3],
            (Am, Extended) => &[2, 4, 5, 6, 7],
            (Am, All) => &[2, 3, 4, 5, 6, 7],
            (Cm, Main) => &[3],
            (Cm, Extended) => &[4, 5, 6],
            (Cm, All) => &[3, 4, 5, 6],
            (Bk, Main) => &[3],
            (Bk, Extended) => &[2, 4, 5],
            (Bk, All) => &[2, 3, 4, 5],
            (Cf, Main) => &[3],
            (Cf, Extended) => &[2, 4, 5],
            (Cf, All) => &[2, 3, 4, 5],
            (Es, Main) => &[3],
            (Es, Extended) => &[2, 4],
            (Es, All) => &[2, 3, 4],
            (Fm, Main) => &[3],
            (Fm, Extended) => &[2],
            (Fm, All) => &[2, 3],
            (Md, Main) => &[3],
            (Md, Extended) => &[2],
            (Md, All) => &[2, 3],
            (No, Main) => &[2],
            (No, Extended) => &[3],
            (No, All) => &[2, 3],
            (Lr, Main) => &[3],
            (Lr, Extended) => &[],
            (Lr, All) => &[3],
            (Rf, Main) => &[4],
            (Rf, Extended) => &[],
            (Rf, All) => &[4],
            (Db, Main) => &[5],
            (Db, Extended) => &[],
            (Db, All) => &[5],
            (Sg, Main) => &[6],
            (Sg, Extended) => &[0],
            (Sg, All) => &[0, 6],
            (Bh, Main) => &[7],
            (Bh, Extended) => &[],
            (Bh, All) => &[7],
            (Hs, Main) => &[8],
            (Hs, Extended) => &[],
            (Hs, All) => &[8],
            (Mt, Main) => &[],
            (Mt, Extended) => &[],
            (Mt, All) => &[],
            (Ds, Main) => &[],
            (Ds, Extended) => &[],
            (Ds, All) => &[],
            (Rg, Main) => &[],
            (Rg, Extended) => &[],
            (Rg, All) => &[],
            (Cn, Main) => &[2],
            (Cn, Extended) => &[],
            (Cn, All) => &[2],
            (Nh, Main) => &[],
            (Nh, Extended) => &[],
            (Nh, All) => &[],
            (Fl, Main) => &[],
            (Fl, Extended) => &[],
            (Fl, All) => &[],
            (Mc, Main) => &[],
            (Mc, Extended) => &[],
            (Mc, All) => &[],
            (Lv, Main) => &[],
            (Lv, Extended) => &[],
            (Lv, All) => &[],
            (Ts, Main) => &[],
            (Ts, Extended) => &[],
            (Ts, All) => &[],
            (Og, Main) => &[],
            (Og, Extended) => &[],
            (Og, All) => &[],
        }
    }
}
